"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QIODevice(QObject, QIODeviceBase):
    """
    https://doc.qt.io/qt-6/qiodevice.html

    **Detailed Description**

    QIODevice provides both a common implementation and an abstract interface
    for devices that support reading and writing of blocks of data, such as
    **QFile** , **QBuffer**  and **QTcpSocket** . QIODevice is abstract and
    cannot be instantiated, but it is common to use the interface it defines to
    provide device-independent I/O features. For example, Qt's XML classes
    operate on a QIODevice pointer, allowing them to be used with various
    devices (such as files and buffers).

    Before accessing the device, **open** () must be called to set the correct
    OpenMode (such as ReadOnly or ReadWrite). You can then write to the device
    with **write** () or **putChar** (), and read by calling either **read** (),
    **readLine** (), or **readAll** (). Call **close** () when you are done with
    the device.

    QIODevice distinguishes between two types of devices: random-access devices
    and sequential devices.

    * Random-access devices support seeking to arbitrary positions using
    **seek** (). The current position in the file is available by calling
    **pos** (). **QFile**  and **QBuffer**  are examples of random-access
    devices.
      * Sequential devices don't support seeking to arbitrary
    positions. The data must be read in one pass. The functions **pos** () and
    **size** () don't work for sequential devices. **QTcpSocket**  and
    **QProcess**  are examples of sequential devices.

    You can use **isSequential** () to determine the type of device.

    QIODevice emits **readyRead** () when new data is available for reading; for
    example, if new data has arrived on the network or if additional data is
    appended to a file that you are reading from. You can call
    **bytesAvailable** () to determine the number of bytes that are currently
    available for reading. It's common to use **bytesAvailable** () together
    with the **readyRead** () signal when programming with asynchronous devices
    such as **QTcpSocket** , where fragments of data can arrive at arbitrary
    points in time. QIODevice emits the **bytesWritten** () signal every time a
    payload of data has been written to the device. Use **bytesToWrite** () to
    determine the current amount of data waiting to be written.

    Certain subclasses of QIODevice, such as **QTcpSocket**  and **QProcess** ,
    are asynchronous. This means that I/O functions such as **write** () or
    **read** () always return immediately, while communication with the device
    itself may happen when control goes back to the event loop. QIODevice
    provides functions that allow you to force these operations to be performed
    immediately, while blocking the calling thread and without entering the
    event loop. This allows QIODevice subclasses to be used without an event
    loop, or in a separate thread:

    * **waitForReadyRead** () - This function suspends operation in the calling
    thread until new data is available for reading.
      * **waitForBytesWritten**
    () - This function suspends operation in the calling thread until one
    payload of data has been written to the device.
      * waitFor....() -
    Subclasses of QIODevice implement blocking functions for device-specific
    operations. For example, **QProcess**  has a function called
    **waitForStarted** () which suspends operation in the calling thread until
    the process has started.

    Calling these functions from the main, GUI thread, may cause your user
    interface to freeze. Example:

    **QProcess**  gzip;
        gzip.start("gzip", **QStringList** () << "-c");
    if (!gzip.waitForStarted())
            return false;
    gzip.write("uncompressed data");

        **QByteArray**  compressed;
    while (gzip.waitForReadyRead())
            compressed += gzip.readAll();

    By subclassing QIODevice, you can provide the same interface to your own I/O
    devices. Subclasses of QIODevice are only required to implement the
    protected **readData** () and **writeData** () functions. QIODevice uses
    these functions to implement all its convenience functions, such as
    **getChar** (), **readLine** () and **write** (). QIODevice also handles
    access control for you, so you can safely assume that the device is opened
    in write mode if **writeData** () is called.

    Some subclasses, such as **QFile**  and **QTcpSocket** , are implemented
    using a memory buffer for intermediate storing of data. This reduces the
    number of required device accessing calls, which are often very slow.
    Buffering makes functions like **getChar** () and **putChar** () fast, as
    they can operate on the memory buffer instead of directly on the device
    itself. Certain I/O operations, however, don't work well with a buffer. For
    example, if several users open the same device and read it character by
    character, they may end up reading the same data when they meant to read a
    separate chunk each. For this reason, QIODevice allows you to bypass any
    buffering by passing the Unbuffered flag to **open** (). When subclassing
    QIODevice, remember to bypass any buffer you may use when the device is open
    in Unbuffered mode.

    Usually, the incoming data stream from an asynchronous device is fragmented,
    and chunks of data can arrive at arbitrary points in time. To handle
    incomplete reads of data structures, use the transaction mechanism
    implemented by QIODevice. See **startTransaction** () and related functions
    for more details.

    Some sequential devices support communicating via multiple channels. These
    channels represent separate streams of data that have the property of
    independently sequenced delivery. Once the device is opened, you can
    determine the number of channels by calling the **readChannelCount** () and
    **writeChannelCount** () functions. To switch between channels, call
    **setCurrentReadChannel** () and **setCurrentWriteChannel** (),
    respectively. QIODevice also provides additional signals to handle
    asynchronous communication on a per-channel basis.

    **See also** **QBuffer** , **QFile** , and **QTcpSocket** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qiodevice.html#QIODevice

        **QIODevice::QIODevice()**

        Constructs a QIODevice object.
        """
        ...

    @typing.overload
    def __init__(self, parent: QObject) -> None:
        """
        https://doc.qt.io/qt-6/qiodevice.html#QIODevice-1

        **QIODevice::QIODevice(QObject * parent )**

        Constructs a QIODevice object with the given **parent**.
        """
        ...

    def setErrorString(self, errorString: str) -> None:
        """
        https://doc.qt.io/qt-6/qiodevice.html#setErrorString

        **[protected] void QIODevice::setErrorString(const QString & str )**

        Sets the human readable description of the last device error that
        occurred to **str**.

        **See also** **errorString** ().
        """
        ...

    def setOpenMode(self, openMode: QIODeviceBase.OpenModeFlag) -> None:
        """
        https://doc.qt.io/qt-6/qiodevice.html#setOpenMode

        **[protected] void QIODevice::setOpenMode(QIODeviceBase::OpenMode
        openMode )**

        Sets the OpenMode of the device to **openMode**. Call this function to
        set the open mode if the flags change after the device has been opened.

        **See also** **openMode** () and **OpenMode** .
        """
        ...

    def skipData(self, maxSize: int) -> int:
        """
        https://doc.qt.io/qt-6/qiodevice.html#skipData

        **[virtual protected, since 6.0] qint64 QIODevice::skipData(qint64
        maxSize )**

        Skips up to **maxSize** bytes from the device. Returns the number of
        bytes actually skipped, or -1 on error.

        This function is called by **QIODevice** . Consider reimplementing it
        when creating a subclass of **QIODevice** .

        The base implementation discards the data by reading into a dummy
        buffer. This is slow, but works for all types of devices. Subclasses can
        reimplement this function to improve on that.

        This function was introduced in Qt 6.0.

        **See also** **skip** (), **peek** (), **seek** (), and **read** ().
        """
        ...

    def writeData(self, a0: PyQt6.sip.Buffer) -> int:
        """
        https://doc.qt.io/qt-6/qiodevice.html#writeData

        **[pure virtual protected] qint64 QIODevice::writeData(const char * data
        , qint64 maxSize )**

        Writes up to **maxSize** bytes from **data** to the device. Returns the
        number of bytes written, or -1 if an error occurred.

        This function is called by **QIODevice** . Reimplement this function
        when creating a subclass of **QIODevice** .

        When reimplementing this function it is important that this function
        writes all the data available before returning. This is required in
        order for **QDataStream**  to be able to operate on the class.
        **QDataStream**  assumes all the information was written and therefore
        does not retry writing if there was a problem.

        **See also** **read** () and **write** ().
        """
        ...

    def readLineData(self, maxlen: int) -> bytes:
        """
        https://doc.qt.io/qt-6/qiodevice.html#readLineData

        **[virtual protected] qint64 QIODevice::readLineData(char * data ,
        qint64 maxSize )**

        Reads up to **maxSize** characters into **data** and returns the number
        of characters read.

        This function is called by **readLine** (), and provides its base
        implementation, using **getChar** (). Buffered devices can improve the
        performance of **readLine** () by reimplementing this function.

        **readLine** () appends a '\\0' byte to **data** ; readLineData() does
        not need to do this.

        If you reimplement this function, be careful to return the correct
        value: it should return the number of bytes read in this line, including
        the terminating newline, or 0 if there is no line to be read at this
        point. If an error occurs, it should return -1 if and only if no bytes
        were read. Reading past EOF is considered an error.
        """
        ...

    def readData(self, maxlen: int) -> bytes:
        """
        https://doc.qt.io/qt-6/qiodevice.html#readData

        **[pure virtual protected] qint64 QIODevice::readData(char * data ,
        qint64 maxSize )**

        Reads up to **maxSize** bytes from the device into **data** , and
        returns the number of bytes read or -1 if an error occurred.

        If there are no bytes to be read and there can never be more bytes
        available (examples include socket closed, pipe closed, sub-process
        finished), this function returns -1.

        This function is called by **QIODevice** . Reimplement this function
        when creating a subclass of **QIODevice** .

        When reimplementing this function it is important that this function
        reads all the required data before returning. This is required in order
        for **QDataStream**  to be able to operate on the class. **QDataStream**
        assumes all the requested information was read and therefore does not
        retry reading if there was a problem.

        This function might be called with a maxSize of 0, which can be used to
        perform post-reading operations.

        **See also** **read** (), **readLine** (), and **writeData** ().
        """
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qiodevice.html#errorString

        **QString QIODevice::errorString() const**

        Returns a human-readable description of the last device error that
        occurred.

        **See also** **setErrorString** ().
        """
        ...

    def getChar(self) -> typing.Tuple[bool, bytes]:
        """
        https://doc.qt.io/qt-6/qiodevice.html#getChar

        **bool QIODevice::getChar(char * c )**

        Reads one character from the device and stores it in **c**. If **c** is
        `nullptr`, the character is discarded. Returns `true` on success;
        otherwise returns `false`.

        **See also** **read** (), **putChar** (), and **ungetChar** ().
        """
        ...

    def putChar(self, c: bytes) -> bool:
        """
        https://doc.qt.io/qt-6/qiodevice.html#putChar

        **bool QIODevice::putChar(char c )**

        Writes the character **c** to the device. Returns `true` on success;
        otherwise returns `false`.

        **See also** **write** (), **getChar** (), and **ungetChar** ().
        """
        ...

    def ungetChar(self, c: bytes) -> None:
        """
        https://doc.qt.io/qt-6/qiodevice.html#ungetChar

        **void QIODevice::ungetChar(char c )**

        Puts the character **c** back into the device, and decrements the
        current position unless the position is 0. This function is usually
        called to "undo" a **getChar** () operation, such as when writing a
        backtracking parser.

        If **c** was not previously read from the device, the behavior is
        undefined.

        **Note:** This function is not available while a transaction is in
        progress.
        """
        ...

    def waitForBytesWritten(self, msecs: int) -> bool:
        """
        https://doc.qt.io/qt-6/qiodevice.html#waitForBytesWritten

        **[virtual] bool QIODevice::waitForBytesWritten(int msecs )**

        For buffered devices, this function waits until a payload of buffered
        written data has been written to the device and the **bytesWritten** ()
        signal has been emitted, or until **msecs** milliseconds have passed. If
        msecs is -1, this function will not time out. For unbuffered devices, it
        returns immediately.

        Returns `true` if a payload of data was written to the device; otherwise
        returns `false` (i.e. if the operation timed out, or if an error
        occurred).

        This function can operate without an event loop. It is useful when
        writing non-GUI applications and when performing I/O operations in a
        non-GUI thread.

        If called from within a slot connected to the **bytesWritten** ()
        signal, **bytesWritten** () will not be reemitted.

        Reimplement this function to provide a blocking API for a custom device.
        The default implementation does nothing, and returns `false`.

        **Warning:** Calling this function from the main (GUI) thread might
        cause your user interface to freeze.

        **See also** **waitForReadyRead** ().
        """
        ...

    def waitForReadyRead(self, msecs: int) -> bool:
        """
        https://doc.qt.io/qt-6/qiodevice.html#waitForReadyRead

        **[virtual] bool QIODevice::waitForReadyRead(int msecs )**

        Blocks until new data is available for reading and the **readyRead** ()
        signal has been emitted, or until **msecs** milliseconds have passed. If
        msecs is -1, this function will not time out.

        Returns `true` if new data is available for reading; otherwise returns
        false (if the operation timed out or if an error occurred).

        This function can operate without an event loop. It is useful when
        writing non-GUI applications and when performing I/O operations in a
        non-GUI thread.

        If called from within a slot connected to the **readyRead** () signal,
        **readyRead** () will not be reemitted.

        Reimplement this function to provide a blocking API for a custom device.
        The default implementation does nothing, and returns `false`.

        **Warning:** Calling this function from the main (GUI) thread might
        cause your user interface to freeze.

        **See also** **waitForBytesWritten** ().
        """
        ...

    def skip(self, maxSize: int) -> int:
        """
        https://doc.qt.io/qt-6/qiodevice.html#skip

        **[since 5.10] qint64 QIODevice::skip(qint64 maxSize )**

        Skips up to **maxSize** bytes from the device. Returns the number of
        bytes actually skipped, or -1 on error.

        This function does not wait and only discards the data that is already
        available for reading.

        If the device is opened in text mode, end-of-line terminators are
        translated to '\\n' symbols and count as a single byte identically to the
        **read** () and **peek** () behavior.

        This function works for all devices, including sequential ones that
        cannot **seek** (). It is optimized to skip unwanted data after a
        **peek** () call.

        For random-access devices, skip() can be used to seek forward from the
        current position. Negative **maxSize** values are not allowed.

        This function was introduced in Qt 5.10.

        **See also** **skipData** (), **peek** (), **seek** (), and **read** ().
        """
        ...

    def peek(self, maxlen: int) -> bytes:
        """
        https://doc.qt.io/qt-6/qiodevice.html#peek

        **qint64 QIODevice::peek(char * data , qint64 maxSize )**

        Reads at most **maxSize** bytes from the device into **data** , without
        side effects (i.e., if you call **read** () after peek(), you will get
        the same data). Returns the number of bytes read. If an error occurs,
        such as when attempting to peek a device opened in WriteOnly mode, this
        function returns -1.

        0 is returned when no more data is available for reading.

        Example:

        bool isExeFile(**QFile**  *file)
            {
                char buf[2];
                if
        (file->peek(buf, sizeof(buf)) == sizeof(buf))
                    return (buf[0]
        == 'M' && buf[1] == 'Z');
                return false;
            }

        **See also** **read** ().
        """
        ...

    def write(self, a0: PyQt6.sip.Buffer) -> int:
        """
        https://doc.qt.io/qt-6/qiodevice.html#write

        **qint64 QIODevice::write(const char * data , qint64 maxSize )**

        Writes at most **maxSize** bytes of data from **data** to the device.
        Returns the number of bytes that were actually written, or -1 if an
        error occurred.

        **See also** **read** () and **writeData** ().
        """
        ...

    def isTransactionStarted(self) -> bool:
        """
        https://doc.qt.io/qt-6/qiodevice.html#isTransactionStarted

        **[since 5.7] bool QIODevice::isTransactionStarted() const**

        Returns `true` if a transaction is in progress on the device, otherwise
        `false`.

        This function was introduced in Qt 5.7.

        **See also** **startTransaction** ().
        """
        ...

    def rollbackTransaction(self) -> None:
        """
        https://doc.qt.io/qt-6/qiodevice.html#rollbackTransaction

        **[since 5.7] void QIODevice::rollbackTransaction()**

        Rolls back a read transaction.

        Restores the input stream to the point of the **startTransaction** ()
        call. This function is commonly used to rollback the transaction when an
        incomplete read was detected prior to committing the transaction.

        This function was introduced in Qt 5.7.

        **See also** **startTransaction** () and **commitTransaction** ().
        """
        ...

    def commitTransaction(self) -> None:
        """
        https://doc.qt.io/qt-6/qiodevice.html#commitTransaction

        **[since 5.7] void QIODevice::commitTransaction()**

        Completes a read transaction.

        For sequential devices, all data recorded in the internal buffer during
        the transaction will be discarded.

        This function was introduced in Qt 5.7.

        **See also** **startTransaction** () and **rollbackTransaction** ().
        """
        ...

    def startTransaction(self) -> None:
        """
        https://doc.qt.io/qt-6/qiodevice.html#startTransaction

        **[since 5.7] void QIODevice::startTransaction()**

        Starts a new read transaction on the device.

        Defines a restorable point within the sequence of read operations. For
        sequential devices, read data will be duplicated internally to allow
        recovery in case of incomplete reads. For random-access devices, this
        function saves the current position. Call **commitTransaction** () or
        **rollbackTransaction** () to finish the transaction.

        **Note:** Nesting transactions is not supported.

        This function was introduced in Qt 5.7.

        **See also** **commitTransaction** () and **rollbackTransaction** ().
        """
        ...

    def canReadLine(self) -> bool:
        """
        https://doc.qt.io/qt-6/qiodevice.html#canReadLine

        **[virtual] bool QIODevice::canReadLine() const**

        Returns `true` if a complete line of data can be read from the device;
        otherwise returns `false`.

        Note that unbuffered devices, which have no way of determining what can
        be read, always return false.

        This function is often called in conjunction with the **readyRead** ()
        signal.

        Subclasses that reimplement this function must call the base
        implementation in order to include the contents of the **QIODevice** 's
        buffer. Example:

        bool CustomDevice::canReadLine() const
            {
                return
        buffer.contains('\\n') || **QIODevice** ::canReadLine();
            }

        **See also** **readyRead** () and **readLine** ().
        """
        ...

    def readAll(self) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qiodevice.html#readAll

        **QByteArray QIODevice::readAll()**

        Reads all remaining data from the device, and returns it as a byte
        array.

        This function has no way of reporting errors; returning an empty
        **QByteArray**  can mean either that no data was currently available for
        reading, or that an error occurred.
        """
        ...

    @typing.overload
    def readLine(self, maxlen: int) -> bytes:
        """
        https://doc.qt.io/qt-6/qiodevice.html#readLine

        **qint64 QIODevice::readLine(char * data , qint64 maxSize )**

        This function reads a line of ASCII characters from the device, up to a
        maximum of **maxSize** \\- 1 bytes, stores the characters in **data** ,
        and returns the number of bytes read. If a line could not be read but no
        error occurred, this function returns 0. If an error occurs, this
        function returns the length of what could be read, or -1 if nothing was
        read.

        A terminating '\\0' byte is always appended to **data** , so **maxSize**
        must be larger than 1.

        Data is read until either of the following conditions are met:

        * The first '\\n' character is read.
          * **maxSize** \\- 1 bytes are read.
        * The end of the device data is detected.

        For example, the following code reads a line of characters from a file:

        **QFile**  file("box.txt");
            if (file.open(**QFile** ::ReadOnly)) {
        char buf[1024];
                **qint64**  lineLength = file.readLine(buf,
        sizeof(buf));
                if (lineLength != -1) {
                    // the line is
        available in buf
                }
            }

        The newline character ('\\n') is included in the buffer. If a newline is
        not encountered before maxSize - 1 bytes are read, a newline will not be
        inserted into the buffer. On windows newline characters are replaced
        with '\\n'.

        Note that on sequential devices, data may not be immediately available,
        which may result in a partial line being returned. By calling the
        **canReadLine** () function before reading, you can check whether a
        complete line (including the newline character) can be read.

        This function calls **readLineData** (), which is implemented using
        repeated calls to **getChar** (). You can provide a more efficient
        implementation by reimplementing **readLineData** () in your own
        subclass.

        **See also** **getChar** (), **read** (), **canReadLine** (), and
        **write** ().
        """
        ...

    @typing.overload
    def readLine(self) -> "QByteArray":
        """
        https://doc.qt.io/qt-6/qiodevice.html#readLine-1

        **QByteArray QIODevice::readLine(qint64 maxSize = 0)**

        This is an overloaded function.

        Reads a line from the device, but no more than **maxSize** characters,
        and returns the result as a byte array.

        This function has no way of reporting errors; returning an empty
        **QByteArray**  can mean either that no data was currently available for
        reading, or that an error occurred.
        """
        ...

    def read(self, maxlen: int) -> bytes:
        """
        https://doc.qt.io/qt-6/qiodevice.html#read

        **qint64 QIODevice::read(char * data , qint64 maxSize )**

        Reads at most **maxSize** bytes from the device into **data** , and
        returns the number of bytes read. If an error occurs, such as when
        attempting to read from a device opened in WriteOnly mode, this function
        returns -1.

        0 is returned when no more data is available for reading. However,
        reading past the end of the stream is considered an error, so this
        function returns -1 in those cases (that is, reading on a closed socket
        or after a process has died).

        **See also** **readData** (), **readLine** (), and **write** ().
        """
        ...

    def bytesToWrite(self) -> int:
        """
        https://doc.qt.io/qt-6/qiodevice.html#bytesToWrite

        **[virtual] qint64 QIODevice::bytesToWrite() const**

        For buffered devices, this function returns the number of bytes waiting
        to be written. For devices with no buffer, this function returns 0.

        Subclasses that reimplement this function must call the base
        implementation in order to include the size of the buffer of
        **QIODevice** .

        **See also** **bytesAvailable** (), **bytesWritten** (), and
        **isSequential** ().
        """
        ...

    def bytesAvailable(self) -> int:
        """
        https://doc.qt.io/qt-6/qiodevice.html#bytesAvailable

        **[virtual] qint64 QIODevice::bytesAvailable() const**

        Returns the number of bytes that are available for reading. This
        function is commonly used with sequential devices to determine the
        number of bytes to allocate in a buffer before reading.

        Subclasses that reimplement this function must call the base
        implementation in order to include the size of the buffer of
        **QIODevice** . Example:

        **qint64**  CustomDevice::bytesAvailable() const
            {
                return
        buffer.size() + **QIODevice** ::bytesAvailable();
            }

        **See also** **bytesToWrite** (), **readyRead** (), and **isSequential**
        ().
        """
        ...

    def reset(self) -> bool:
        """
        https://doc.qt.io/qt-6/qiodevice.html#reset

        **[virtual] bool QIODevice::reset()**

        Seeks to the start of input for random-access devices. Returns true on
        success; otherwise returns `false` (for example, if the device is not
        open).

        Note that when using a **QTextStream**  on a **QFile** , calling reset()
        on the **QFile**  will not have the expected result because
        **QTextStream**  buffers the file. Use the **QTextStream::seek** ()
        function instead.

        **See also** **seek** ().
        """
        ...

    def atEnd(self) -> bool:
        """
        https://doc.qt.io/qt-6/qiodevice.html#atEnd

        **[virtual] bool QIODevice::atEnd() const**

        Returns `true` if the current read and write position is at the end of
        the device (i.e. there is no more data available for reading on the
        device); otherwise returns `false`.

        For some devices, atEnd() can return true even though there is more data
        to read. This special case only applies to devices that generate data in
        direct response to you calling **read** () (e.g., `/dev` or `/proc`
        files on Unix and macOS, or console input / `stdin` on all platforms).

        **See also** **bytesAvailable** (), **read** (), and **isSequential**
        ().
        """
        ...

    def seek(self, pos: int) -> bool:
        """
        https://doc.qt.io/qt-6/qiodevice.html#seek

        **[virtual] bool QIODevice::seek(qint64 pos )**

        For random-access devices, this function sets the current position to
        **pos** , returning true on success, or false if an error occurred. For
        sequential devices, the default behavior is to produce a warning and
        return false.

        When subclassing **QIODevice** , you must call QIODevice::seek() at the
        start of your function to ensure integrity with **QIODevice** 's built-
        in buffer.

        **See also** **pos** () and **isSequential** ().
        """
        ...

    def size(self) -> int:
        """
        https://doc.qt.io/qt-6/qiodevice.html#size

        **[virtual] qint64 QIODevice::size() const**

        For open random-access devices, this function returns the size of the
        device. For open sequential devices, **bytesAvailable** () is returned.

        If the device is closed, the size returned will not reflect the actual
        size of the device.

        **See also** **isSequential** () and **pos** ().
        """
        ...

    def pos(self) -> int:
        """
        https://doc.qt.io/qt-6/qiodevice.html#pos

        **[virtual] qint64 QIODevice::pos() const**

        For random-access devices, this function returns the position that data
        is written to or read from. For sequential devices or closed devices,
        where there is no concept of a "current position", 0 is returned.

        The current read/write position of the device is maintained internally
        by **QIODevice** , so reimplementing this function is not necessary.
        When subclassing **QIODevice** , use **QIODevice::seek** () to notify
        **QIODevice**  about changes in the device position.

        **See also** **isSequential** () and **seek** ().
        """
        ...

    def close(self) -> None:
        """
        https://doc.qt.io/qt-6/qiodevice.html#close

        **[virtual] void QIODevice::close()**

        First emits **aboutToClose** (), then closes the device and sets its
        OpenMode to NotOpen. The error string is also reset.

        **See also** **setOpenMode** () and **QIODeviceBase::OpenMode** .
        """
        ...

    def open(self, mode: QIODeviceBase.OpenModeFlag) -> bool:
        """
        https://doc.qt.io/qt-6/qiodevice.html#open

        **[virtual] bool QIODevice::open(QIODeviceBase::OpenMode mode )**

        Opens the device and sets its OpenMode to **mode**. Returns `true` if
        successful; otherwise returns `false`. This function should be called
        from any reimplementations of open() or other functions that open the
        device.

        **See also** **openMode** () and **QIODeviceBase::OpenMode** .
        """
        ...

    def setCurrentWriteChannel(self, channel: int) -> None:
        """
        https://doc.qt.io/qt-6/qiodevice.html#setCurrentWriteChannel

        **[since 5.7] void QIODevice::setCurrentWriteChannel(int channel )**

        Sets the current write channel of the **QIODevice**  to the given
        **channel**. The current output channel is used by the functions
        **write** (), **putChar** (). It also determines which channel triggers
        **QIODevice**  to emit **bytesWritten** ().

        This function was introduced in Qt 5.7.

        **See also** **currentWriteChannel** () and **writeChannelCount** ().
        """
        ...

    def currentWriteChannel(self) -> int:
        """
        https://doc.qt.io/qt-6/qiodevice.html#currentWriteChannel

        **[since 5.7] int QIODevice::currentWriteChannel() const**

        Returns the index of the current write channel.

        This function was introduced in Qt 5.7.

        **See also** **setCurrentWriteChannel** () and **writeChannelCount** ().
        """
        ...

    def setCurrentReadChannel(self, channel: int) -> None:
        """
        https://doc.qt.io/qt-6/qiodevice.html#setCurrentReadChannel

        **[since 5.7] void QIODevice::setCurrentReadChannel(int channel )**

        Sets the current read channel of the **QIODevice**  to the given
        **channel**. The current input channel is used by the functions **read**
        (), **readAll** (), **readLine** (), and **getChar** (). It also
        determines which channel triggers **QIODevice**  to emit **readyRead**
        ().

        This function was introduced in Qt 5.7.

        **See also** **currentReadChannel** (), **readChannelCount** (), and
        **QProcess** .
        """
        ...

    def currentReadChannel(self) -> int:
        """
        https://doc.qt.io/qt-6/qiodevice.html#currentReadChannel

        **[since 5.7] int QIODevice::currentReadChannel() const**

        Returns the index of the current read channel.

        This function was introduced in Qt 5.7.

        **See also** **setCurrentReadChannel** (), **readChannelCount** (), and
        **QProcess** .
        """
        ...

    def writeChannelCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qiodevice.html#writeChannelCount

        **[since 5.7] int QIODevice::writeChannelCount() const**

        Returns the number of available write channels if the device is open;
        otherwise returns 0.

        This function was introduced in Qt 5.7.

        **See also** **readChannelCount** ().
        """
        ...

    def readChannelCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qiodevice.html#readChannelCount

        **[since 5.7] int QIODevice::readChannelCount() const**

        Returns the number of available read channels if the device is open;
        otherwise returns 0.

        This function was introduced in Qt 5.7.

        **See also** **writeChannelCount** () and **QProcess** .
        """
        ...

    def isSequential(self) -> bool:
        """
        https://doc.qt.io/qt-6/qiodevice.html#isSequential

        **[virtual] bool QIODevice::isSequential() const**

        Returns `true` if this device is sequential; otherwise returns false.

        Sequential devices, as opposed to a random-access devices, have no
        concept of a start, an end, a size, or a current position, and they do
        not support seeking. You can only read from the device when it reports
        that data is available. The most common example of a sequential device
        is a network socket. On Unix, special files such as /dev/zero and fifo
        pipes are sequential.

        Regular files, on the other hand, do support random access. They have
        both a size and a current position, and they also support seeking
        backwards and forwards in the data stream. Regular files are non-
        sequential.

        **See also** **bytesAvailable** ().
        """
        ...

    def isWritable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qiodevice.html#isWritable

        **bool QIODevice::isWritable() const**

        Returns `true` if data can be written to the device; otherwise returns
        false.

        This is a convenience function which checks if the OpenMode of the
        device contains the WriteOnly flag.

        **See also** **openMode** () and **OpenMode** .
        """
        ...

    def isReadable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qiodevice.html#isReadable

        **bool QIODevice::isReadable() const**

        Returns `true` if data can be read from the device; otherwise returns
        false. Use **bytesAvailable** () to determine how many bytes can be
        read.

        This is a convenience function which checks if the OpenMode of the
        device contains the ReadOnly flag.

        **See also** **openMode** () and **OpenMode** .
        """
        ...

    def isOpen(self) -> bool:
        """
        https://doc.qt.io/qt-6/qiodevice.html#isOpen

        **bool QIODevice::isOpen() const**

        Returns `true` if the device is open; otherwise returns `false`. A
        device is open if it can be read from and/or written to. By default,
        this function returns `false` if **openMode** () returns `NotOpen`.

        **See also** **openMode** () and **QIODeviceBase::OpenMode** .
        """
        ...

    def isTextModeEnabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qiodevice.html#isTextModeEnabled

        **bool QIODevice::isTextModeEnabled() const**

        Returns `true` if the **Text**  flag is enabled; otherwise returns
        `false`.

        **See also** **setTextModeEnabled** ().
        """
        ...

    def setTextModeEnabled(self, enabled: bool) -> None:
        """
        https://doc.qt.io/qt-6/qiodevice.html#setTextModeEnabled

        **void QIODevice::setTextModeEnabled(bool enabled )**

        If **enabled** is true, this function sets the **Text**  flag on the
        device; otherwise the **Text**  flag is removed. This feature is useful
        for classes that provide custom end-of-line handling on a **QIODevice**
        .

        The IO device should be opened before calling this function.

        **See also** **isTextModeEnabled** (), **open** (), and **setOpenMode**
        ().
        """
        ...

    def openMode(self) -> QIODeviceBase.OpenModeFlag:
        """
        https://doc.qt.io/qt-6/qiodevice.html#openMode

        **QIODeviceBase::OpenMode QIODevice::openMode() const**

        Returns the mode in which the device has been opened; i.e. ReadOnly or
        WriteOnly.

        **See also** **setOpenMode** () and **OpenMode** .
        """
        ...

    @property
    def aboutToClose(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qiodevice.html#aboutToClose

        **[signal] void QIODevice::aboutToClose()**

        This signal is emitted when the device is about to close. Connect this
        signal if you have operations that need to be performed before the
        device closes (e.g., if you have data in a separate buffer that needs to
        be written to the device).
        """
        ...

    @property
    def bytesWritten(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qiodevice.html#bytesWritten

        **[signal] void QIODevice::bytesWritten(qint64 bytes )**

        This signal is emitted every time a payload of data has been written to
        the device's current write channel. The **bytes** argument is set to the
        number of bytes that were written in this payload.

        bytesWritten() is not emitted recursively; if you reenter the event loop
        or call **waitForBytesWritten** () inside a slot connected to the
        bytesWritten() signal, the signal will not be reemitted (although
        **waitForBytesWritten** () may still return true).

        **See also** **readyRead** ().
        """
        ...

    @property
    def channelBytesWritten(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qiodevice.html#channelBytesWritten

        **[signal, since 5.7] void QIODevice::channelBytesWritten(int channel ,
        qint64 bytes )**

        This signal is emitted every time a payload of data has been written to
        the device. The **bytes** argument is set to the number of bytes that
        were written in this payload, while **channel** is the channel they were
        written to. Unlike **bytesWritten** (), it is emitted regardless of the
        **current write channel** .

        channelBytesWritten() can be emitted recursively - even for the same
        channel.

        This function was introduced in Qt 5.7.

        **See also** **bytesWritten** () and **channelReadyRead** ().
        """
        ...

    @property
    def channelReadyRead(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qiodevice.html#channelReadyRead

        **[signal, since 5.7] void QIODevice::channelReadyRead(int channel )**

        This signal is emitted when new data is available for reading from the
        device. The **channel** argument is set to the index of the read channel
        on which the data has arrived. Unlike **readyRead** (), it is emitted
        regardless of the **current read channel** .

        channelReadyRead() can be emitted recursively - even for the same
        channel.

        This function was introduced in Qt 5.7.

        **See also** **readyRead** () and **channelBytesWritten** ().
        """
        ...

    @property
    def readChannelFinished(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qiodevice.html#readChannelFinished

        **[signal] void QIODevice::readChannelFinished()**

        This signal is emitted when the input (reading) stream is closed in this
        device. It is emitted as soon as the closing is detected, which means
        that there might still be data available for reading with **read** ().

        **See also** **atEnd** () and **read** ().
        """
        ...

    @property
    def readyRead(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qiodevice.html#readyRead

        **[signal] void QIODevice::readyRead()**

        This signal is emitted once every time new data is available for reading
        from the device's current read channel. It will only be emitted again
        once new data is available, such as when a new payload of network data
        has arrived on your network socket, or when a new block of data has been
        appended to your device.

        readyRead() is not emitted recursively; if you reenter the event loop or
        call **waitForReadyRead** () inside a slot connected to the readyRead()
        signal, the signal will not be reemitted (although **waitForReadyRead**
        () may still return true).

        Note for developers implementing classes derived from **QIODevice** :
        you should always emit readyRead() when new data has arrived (do not
        emit it only because there's data still to be read in your buffers). Do
        not emit readyRead() in other conditions.

        **See also** **bytesWritten** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from ._functions import PYQT_SIGNAL as PYQT_SIGNAL
from ._functions import PYQT_SLOT as PYQT_SLOT
from ._QDomImplementation import QDomImplementation as QDomImplementation
from ._QDomNode import QDomNode as QDomNode
from ._QDomNodeList import QDomNodeList as QDomNodeList
from ._QDomDocumentType import QDomDocumentType as QDomDocumentType
from ._QDomDocument import QDomDocument as QDomDocument
from ._QDomNamedNodeMap import QDomNamedNodeMap as QDomNamedNodeMap
from ._QDomDocumentFragment import QDomDocumentFragment as QDomDocumentFragment
from ._QDomCharacterData import QDomCharacterData as QDomCharacterData
from ._QDomAttr import QDomAttr as QDomAttr
from ._QDomElement import QDomElement as QDomElement
from ._QDomText import QDomText as QDomText
from ._QDomComment import QDomComment as QDomComment
from ._QDomCDATASection import QDomCDATASection as QDomCDATASection
from ._QDomNotation import QDomNotation as QDomNotation
from ._QDomEntity import QDomEntity as QDomEntity
from ._QDomEntityReference import QDomEntityReference as QDomEntityReference
from ._QDomProcessingInstruction import (
    QDomProcessingInstruction as QDomProcessingInstruction,
)



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore


class QMoveEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qmoveevent.html

    **Detailed Description**

    Move events are sent to widgets that have been moved to a new position
    relative to their parent.

    The event handler **QWidget::moveEvent** () receives move events.

    **See also** **QWidget::move** () and **QWidget::setGeometry** ().
    """

    def __init__(self, pos: QtCore.QPoint, oldPos: QtCore.QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qmoveevent.html#QMoveEvent-2

        **QMoveEvent::QMoveEvent(const QPoint & pos , const QPoint & oldPos )**

        Constructs a move event with the new and old widget positions, **pos**
        and **oldPos** respectively.
        """
        ...

    def clone(self) -> "QMoveEvent":
        ...

    def oldPos(self) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qmoveevent.html#oldPos

        **const QPoint &QMoveEvent::oldPos() const**

        Returns the old position of the widget.
        """
        ...

    def pos(self) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qmoveevent.html#pos

        **const QPoint &QMoveEvent::pos() const**

        Returns the new position of the widget. This excludes the window frame
        for top level widgets.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore


class QQmlError(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qqmlerror.html

    **Detailed Description**

    QQmlError includes a textual description of the error, as well as location
    information (the file, line, and column). The **toString** () method creates
    a single-line, human-readable string containing all of this information, for
    example:

    file:///home/user/test.qml:7:8: Invalid property assignment: double expected

    You can use **qDebug** (), **qInfo** (), or **qWarning** () to output errors
    to the console. This method will attempt to open the file indicated by the
    error and include additional contextual information.

    file:///home/user/test.qml:7:8: Invalid property assignment: double expected
    y: "hello"
                   ^

    **See also** **QQuickView::errors** () and **QQmlComponent::errors** ().
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qqmlerror.html#QQmlError

        **QQmlError::QQmlError()**

        Creates an empty error object.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QQmlError") -> None:
        """
        https://doc.qt.io/qt-6/qqmlerror.html#QQmlError-1

        **QQmlError::QQmlError(const QQmlError & other )**

        Creates a copy of **other**.
        """
        ...

    def setMessageType(self, messageType: QtCore.QtMsgType) -> None:
        """
        https://doc.qt.io/qt-6/qqmlerror.html#setMessageType

        **[since 5.9] void QQmlError::setMessageType(QtMsgType messageType )**

        Sets the **messageType** for this message. The message type determines
        which **QDebug**  handlers are responsible for receiving the message.

        This function was introduced in Qt 5.9.

        **See also** **messageType** ().
        """
        ...

    def messageType(self) -> QtCore.QtMsgType:
        """
        https://doc.qt.io/qt-6/qqmlerror.html#messageType

        **[since 5.9] QtMsgType QQmlError::messageType() const**

        Returns the message type.

        This function was introduced in Qt 5.9.

        **See also** **setMessageType** ().
        """
        ...

    def setObject(self, a0: QtCore.QObject) -> None:
        """
        https://doc.qt.io/qt-6/qqmlerror.html#setObject

        **void QQmlError::setObject(QObject * object )**

        Sets the nearest **object** where this error occurred.

        **See also** **object** ().
        """
        ...

    def object(self) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qqmlerror.html#object

        **QObject *QQmlError::object() const**

        Returns the nearest object where this error occurred. Exceptions in
        bound property expressions set this to the object to which the property
        belongs. It will be 0 for all other exceptions.

        **See also** **setObject** ().
        """
        ...

    def toString(self) -> str:
        """
        https://doc.qt.io/qt-6/qqmlerror.html#toString

        **QString QQmlError::toString() const**

        Returns the error as a human readable string.
        """
        ...

    def setColumn(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qqmlerror.html#setColumn

        **void QQmlError::setColumn(int column )**

        Sets the error **column** number.

        **See also** **column** ().
        """
        ...

    def column(self) -> int:
        """
        https://doc.qt.io/qt-6/qqmlerror.html#column

        **int QQmlError::column() const**

        Returns the error column number.

        **See also** **setColumn** ().
        """
        ...

    def setLine(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qqmlerror.html#setLine

        **void QQmlError::setLine(int line )**

        Sets the error **line** number.

        **See also** **line** ().
        """
        ...

    def line(self) -> int:
        """
        https://doc.qt.io/qt-6/qqmlerror.html#line

        **int QQmlError::line() const**

        Returns the error line number.

        **See also** **setLine** ().
        """
        ...

    def setDescription(self, a0: str) -> None:
        """
        https://doc.qt.io/qt-6/qqmlerror.html#setDescription

        **void QQmlError::setDescription(const QString & description )**

        Sets the error **description**.

        **See also** **description** ().
        """
        ...

    def description(self) -> str:
        """
        https://doc.qt.io/qt-6/qqmlerror.html#description

        **QString QQmlError::description() const**

        Returns the error description.

        **See also** **setDescription** ().
        """
        ...

    def setUrl(self, a0: QtCore.QUrl) -> None:
        """
        https://doc.qt.io/qt-6/qqmlerror.html#setUrl

        **void QQmlError::setUrl(const QUrl & url )**

        Sets the **url** for the file that caused this error.

        **See also** **url** ().
        """
        ...

    def url(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qqmlerror.html#url

        **QUrl QQmlError::url() const**

        Returns the url for the file that caused this error.

        **See also** **setUrl** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlerror.html#isValid

        **bool QQmlError::isValid() const**

        Returns true if this error is valid, otherwise false.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtBluetooth import *
import enum


class QLowEnergyCharacteristic(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qlowenergycharacteristic.html

    **Detailed Description**

    QLowEnergyCharacteristic provides information about a Bluetooth Low Energy
    service characteristic's **name** (), **uuid** (), **value** (),
    **properties** (), and **descriptors** (). To obtain the characteristic's
    specification and information, it is necessary to connect to the device
    using the **QLowEnergyService**  and **QLowEnergyController**  classes.

    The characteristic value may be written via the **QLowEnergyService**
    instance that manages the service to which this characteristic belongs. The
    **QLowEnergyService::writeCharacteristic** () function writes the new value.
    The **QLowEnergyService::characteristicWritten** () signal is emitted upon
    success. The **value** () of this object is automatically updated
    accordingly.

    Characteristics may contain none, one or more descriptors. They can be
    individually retrieved using the **descriptor** () function. The
    **descriptors** () function returns all descriptors as a list. The general
    purpose of a descriptor is to add contextual information to the
    characteristic. For example, the descriptor might provide format or range
    information specifying how the characteristic's value is to be interpreted.

    **See also** **QLowEnergyService**  and **QLowEnergyDescriptor** .
    """

    class PropertyType(enum.Flag):
        Unknown: QLowEnergyCharacteristic = ...
        Broadcasting: QLowEnergyCharacteristic = ...
        Read: QLowEnergyCharacteristic = ...
        WriteNoResponse: QLowEnergyCharacteristic = ...
        Write: QLowEnergyCharacteristic = ...
        Notify: QLowEnergyCharacteristic = ...
        Indicate: QLowEnergyCharacteristic = ...
        WriteSigned: QLowEnergyCharacteristic = ...
        ExtendedProperty: QLowEnergyCharacteristic = ...

    CCCDDisable: QtCore = ...
    CCCDEnableIndication: QtCore = ...
    CCCDEnableNotification: QtCore = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristic.html#QLowEnergyCharacter
        istic

        **QLowEnergyCharacteristic::QLowEnergyCharacteristic()**

        Construct a new QLowEnergyCharacteristic. A default-constructed instance
        of this class is always invalid.

        **See also** **isValid** ().
        """
        ...

    @typing.overload
    def __init__(self, other: "QLowEnergyCharacteristic") -> None:
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristic.html#QLowEnergyCharacter
        istic-1

        **QLowEnergyCharacteristic::QLowEnergyCharacteristic(const
        QLowEnergyCharacteristic & other )**

        Construct a new QLowEnergyCharacteristic that is a copy of **other**.

        The two copies continue to share the same underlying data which does not
        detach upon write.
        """
        ...

    def clientCharacteristicConfiguration(self) -> "QLowEnergyDescriptor":
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristic.html#clientCharacteristi
        cConfiguration

        **[since 6.2] QLowEnergyDescriptor
        QLowEnergyCharacteristic::clientCharacteristicConfiguration() const**

        Returns the Client Characteristic Configuration Descriptor or an invalid
        **QLowEnergyDescriptor**  instance if no Client Characteristic
        Configuration Descriptor exists.

        BTLE characteristics can support notifications and/or indications. In
        both cases, the peripheral will inform the central on each change of the
        characteristic's value. In the BTLE attribute protocol, notification
        messages are not confirmed by the central, while indications are
        confirmed. Notifications are considered faster, but unreliable, while
        indications are slower and more reliable.

        If a characteristic supports notification or indication, these can be
        enabled by writing special bit patterns to the Client Characteristic
        Configuration Descriptor. For convenience, these bit patterns are
        provided as **QLowEnergyCharacteristic::CCCDDisable** ,
        **QLowEnergyCharacteristic::CCCDEnableNotification** , and
        **QLowEnergyCharacteristic::CCCDEnableIndication** .

        Enabling e.g. notification for a characteristic named `mycharacteristic`
        in a service called `myservice` could be done using the following code.

        auto cccd = mycharacteristic.clientCharacteristicConfiguration();
            if
        (!cccd.isValid()) {
                // your error handling
                return error;
        }
            myservice->writeDescriptor(cccd, **QLowEnergyCharacteristic**
        ::CCCDEnableNotification);

        **Note:** Calling `characteristic.clientCharacteristicConfiguration()`
        is equivalent to calling `characteristic.descriptor(QBluetoothUuid::Desc
        riptorType::ClientCharacteristicConfiguration)`.

        **Note:** It is not recommended to use both notifications and
        indications on the same characteristic. This applies to both server-side
        when setting up the characteristics, as well as client-side when
        enabling them. The bluetooth stack behavior differs from platform to
        platform and the cross-platform behavior will likely be inconsistent. As
        an example a Bluez Linux client might unconditionally try to enable both
        mechanisms if both are supported, whereas a macOS client might
        unconditionally enable just the notifications. If both are needed
        consider creating two separate characteristics.

        This function was introduced in Qt 6.2.

        **See also** **descriptor** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristic.html#isValid

        **bool QLowEnergyCharacteristic::isValid() const**

        Returns `true` if the **QLowEnergyCharacteristic**  object is valid,
        otherwise returns `false`.

        An invalid characteristic object is not associated with any service
        (default-constructed) or the associated service is no longer valid due
        to a disconnect from the underlying Bluetooth Low Energy device, for
        example. Once the object is invalid it cannot become valid anymore.

        **Note:** If a **QLowEnergyCharacteristic**  instance turns invalid due
        to a disconnect from the underlying device, the information encapsulated
        by the current instance remains as it was at the time of the disconnect.
        Therefore it can be retrieved after the disconnect event.
        """
        ...

    def descriptors(self) -> typing.List["QLowEnergyDescriptor"]:
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristic.html#descriptors

        **QList<QLowEnergyDescriptor> QLowEnergyCharacteristic::descriptors()
        const**

        Returns the list of descriptors belonging to this characteristic;
        otherwise an empty list.

        **See also** **descriptor** ().
        """
        ...

    def descriptor(self, uuid: QBluetoothUuid) -> "QLowEnergyDescriptor":
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristic.html#descriptor

        **QLowEnergyDescriptor QLowEnergyCharacteristic::descriptor(const
        QBluetoothUuid & uuid ) const**

        Returns the descriptor for **uuid** or an invalid
        **QLowEnergyDescriptor**  instance.

        **See also** **descriptors** ().
        """
        ...

    def properties(self) -> "QLowEnergyCharacteristic.PropertyType":
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristic.html#properties

        **QLowEnergyCharacteristic::PropertyTypes
        QLowEnergyCharacteristic::properties() const**

        Returns the properties of the characteristic.

        The properties define the access permissions for the characteristic.
        """
        ...

    def value(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristic.html#value

        **QByteArray QLowEnergyCharacteristic::value() const**

        Returns the cached value of the characteristic.

        If the characteristic's **properties** () permit writing of new values,
        the value can be updated using
        **QLowEnergyService::writeCharacteristic** ().

        The cache is updated during the associated service's **detail
        discovery** , a successful **read** /**write**  operation or when an
        update notification is received.

        The returned **QByteArray**  always remains empty if the characteristic
        does not have the **read permission** . In such cases only the
        **QLowEnergyService::characteristicChanged** () or
        **QLowEnergyService::characteristicWritten** () may provice information
        about the value of this characteristic.
        """
        ...

    def uuid(self) -> QBluetoothUuid:
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristic.html#uuid

        **QBluetoothUuid QLowEnergyCharacteristic::uuid() const**

        Returns the UUID of the characteristic if **isValid** () returns `true`;
        otherwise a **null**  UUID.
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristic.html#name

        **QString QLowEnergyCharacteristic::name() const**

        Returns the human-readable name of the characteristic.

        The name is based on the characteristic's **uuid** () which must have
        been standardized. The complete list of characteristic types can be
        found under **Bluetooth.org Characteristics** .

        The returned string is empty if the **uuid** () is unknown.

        **See also** **QBluetoothUuid::characteristicToString** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore


class QAbstractExtensionFactory(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qabstractextensionfactory.html

    **Detailed Description**

    QAbstractExtensionFactory is not intended to be instantiated directly; use
    the **QExtensionFactory**  instead.

    In **Qt Designer** , extension factories are used to look up and create
    named extensions as they are required. For that reason, when implementing a
    custom extension, you must also create a **QExtensionFactory** , i.e a class
    that is able to make an instance of your extension, and register it using
    **Qt Designer** 's **extension manager** .

    When an extension is required, **Qt Designer** 's **extension manager**
    will run through all its registered factories calling
    **QExtensionFactory::createExtension** () for each until the first one that
    is able to create the requested extension for the selected object, is found.
    This factory will then make an instance of the extension.

    **See also** **QExtensionFactory**  and **QExtensionManager** .
    """

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QAbstractExtensionFactory") -> None:
        ...

    def extension(self, object: QtCore.QObject, iid: str) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qabstractextensionfactory.html#extension

        **[pure virtual] QObject *QAbstractExtensionFactory::extension(QObject *
        object , const QString & iid ) const**

        Returns the extension specified by **iid** for the given **object**.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QAbstractItemDelegate(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qabstractitemdelegate.html

    **Detailed Description**

    A QAbstractItemDelegate provides the interface and common functionality for
    delegates in the model/view architecture. Delegates display individual items
    in views, and handle the editing of model data.

    The QAbstractItemDelegate class is one of the **Model/View Classes**  and is
    part of Qt's **model/view framework** .

    To render an item in a custom way, you must implement **paint** () and
    **sizeHint** (). The **QStyledItemDelegate**  class provides default
    implementations for these functions; if you do not need custom rendering,
    subclass that class instead.

    We give an example of drawing a progress bar in items; in our case for a
    package management program.

    ![](images/widgetdelegate.png)

    We create the `WidgetDelegate` class, which inherits from
    **QStyledItemDelegate** . We do the drawing in the **paint** () function:

    void WidgetDelegate::paint(**QPainter**  *painter, const
    **QStyleOptionViewItem**  &option,
                                   const
    **QModelIndex**  &index) const
        {
            if (index.column() == 1) {
    int progress = index.data().toInt();
    **QStyleOptionProgressBar**  progressBarOption;
    progressBarOption.rect = option.rect;
                progressBarOption.minimum
    = 0;
                progressBarOption.maximum = 100;
    progressBarOption.progress = progress;
                progressBarOption.text =
    **QString** ::number(progress) + "%";
    progressBarOption.textVisible = true;

                **QApplication**
    ::style()->drawControl(**QStyle** ::CE_ProgressBar,
    &progressBarOption, painter);
            } else
    **QStyledItemDelegate** ::paint(painter, option, index);

    Notice that we use a **QStyleOptionProgressBar**  and initialize its
    members. We can then use the current **QStyle**  to draw it.

    To provide custom editing, there are two approaches that can be used. The
    first approach is to create an editor widget and display it directly on top
    of the item. To do this you must reimplement **createEditor** () to provide
    an editor widget, **setEditorData** () to populate the editor with the data
    from the model, and **setModelData** () so that the delegate can update the
    model with data from the editor.

    The second approach is to handle user events directly by reimplementing
    **editorEvent** ().

    **See also** **Model/View Programming** , **QStyledItemDelegate** ,
    **Pixelator Example** , **QStyledItemDelegate** , and **QStyle** .
    """

    class EndEditHint(enum.Enum):
        NoHint: QAbstractItemDelegate = ...
        EditNextItem: QAbstractItemDelegate = ...
        EditPreviousItem: QAbstractItemDelegate = ...
        SubmitModelCache: QAbstractItemDelegate = ...
        RevertModelCache: QAbstractItemDelegate = ...

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemdelegate.html#QAbstractItemDelegate

        **QAbstractItemDelegate::QAbstractItemDelegate(QObject * parent =
        nullptr)**

        Creates a new abstract item delegate with the given **parent**.
        """
        ...

    def helpEvent(
        self,
        event: QtGui.QHelpEvent,
        view: "QAbstractItemView",
        option: "QStyleOptionViewItem",
        index: QtCore.QModelIndex,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractitemdelegate.html#helpEvent

        **[virtual] bool QAbstractItemDelegate::helpEvent(QHelpEvent * event ,
        QAbstractItemView * view , const QStyleOptionViewItem & option , const
        QModelIndex & index )**

        Whenever a help event occurs, this function is called with the **event**
        **view** **option** and the **index** that corresponds to the item where
        the event occurs.

        Returns `true` if the delegate can handle the event; otherwise returns
        `false`. A return value of true indicates that the data obtained using
        the index had the required role.

        For **QEvent::ToolTip**  and **QEvent::WhatsThis**  events that were
        handled successfully, the relevant popup may be shown depending on the
        user's system configuration.

        **See also** **QHelpEvent** .
        """
        ...

    def editorEvent(
        self,
        event: QtCore.QEvent,
        model: QtCore.QAbstractItemModel,
        option: "QStyleOptionViewItem",
        index: QtCore.QModelIndex,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractitemdelegate.html#editorEvent

        **[virtual] bool QAbstractItemDelegate::editorEvent(QEvent * event ,
        QAbstractItemModel * model , const QStyleOptionViewItem & option , const
        QModelIndex & index )**

        When editing of an item starts, this function is called with the
        **event** that triggered the editing, the **model** , the **index** of
        the item, and the **option** used for rendering the item.

        Mouse events are sent to editorEvent() even if they don't start editing
        of the item. This can, for instance, be useful if you wish to open a
        context menu when the right mouse button is pressed on an item.

        The base implementation returns `false` (indicating that it has not
        handled the event).
        """
        ...

    def destroyEditor(self, editor: QWidget, index: QtCore.QModelIndex) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemdelegate.html#destroyEditor

        **[virtual, since 5.0] void QAbstractItemDelegate::destroyEditor(QWidget
        * editor , const QModelIndex & index ) const**

        Called when the **editor** is no longer needed for editing the data item
        with the given **index** and should be destroyed. The default behavior
        is a call to deleteLater on the editor. It is possible e.g. to avoid
        this delete by reimplementing this function.

        This function was introduced in Qt 5.0.

        **See also** **createEditor** ().
        """
        ...

    def updateEditorGeometry(
        self, editor: QWidget, option: "QStyleOptionViewItem", index: QtCore.QModelIndex
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemdelegate.html#updateEditorGeometry

        **[virtual] void QAbstractItemDelegate::updateEditorGeometry(QWidget *
        editor , const QStyleOptionViewItem & option , const QModelIndex & index
        ) const**

        Updates the geometry of the **editor** for the item with the given
        **index** , according to the rectangle specified in the **option**. If
        the item has an internal layout, the editor will be laid out
        accordingly. Note that the index contains information about the model
        being used.

        The base implementation does nothing. If you want custom editing you
        must reimplement this function.
        """
        ...

    def setModelData(
        self,
        editor: QWidget,
        model: QtCore.QAbstractItemModel,
        index: QtCore.QModelIndex,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemdelegate.html#setModelData

        **[virtual] void QAbstractItemDelegate::setModelData(QWidget * editor ,
        QAbstractItemModel * model , const QModelIndex & index ) const**

        Sets the data for the item at the given **index** in the **model** to
        the contents of the given **editor**.

        The base implementation does nothing. If you want custom editing you
        will need to reimplement this function.

        **See also** **setEditorData** ().
        """
        ...

    def setEditorData(self, editor: QWidget, index: QtCore.QModelIndex) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemdelegate.html#setEditorData

        **[virtual] void QAbstractItemDelegate::setEditorData(QWidget * editor ,
        const QModelIndex & index ) const**

        Sets the contents of the given **editor** to the data for the item at
        the given **index**. Note that the index contains information about the
        model being used.

        The base implementation does nothing. If you want custom editing you
        will need to reimplement this function.

        **See also** **setModelData** ().
        """
        ...

    def createEditor(
        self, parent: QWidget, option: "QStyleOptionViewItem", index: QtCore.QModelIndex
    ) -> QWidget:
        """
        https://doc.qt.io/qt-6/qabstractitemdelegate.html#createEditor

        **[virtual] QWidget *QAbstractItemDelegate::createEditor(QWidget *
        parent , const QStyleOptionViewItem & option , const QModelIndex & index
        ) const**

        Returns the editor to be used for editing the data item with the given
        **index**. Note that the index contains information about the model
        being used. The editor's parent widget is specified by **parent** , and
        the item options by **option**.

        The base implementation returns `nullptr`. If you want custom editing
        you will need to reimplement this function.

        The returned editor widget should have **Qt::StrongFocus** ; otherwise,
        **QMouseEvent** s received by the widget will propagate to the view. The
        view's background will shine through unless the editor paints its own
        background (e.g., with **setAutoFillBackground** ()).

        **See also** **destroyEditor** (), **setModelData** (), and
        **setEditorData** ().
        """
        ...

    def sizeHint(
        self, option: "QStyleOptionViewItem", index: QtCore.QModelIndex
    ) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qabstractitemdelegate.html#sizeHint

        **[pure virtual] QSize QAbstractItemDelegate::sizeHint(const
        QStyleOptionViewItem & option , const QModelIndex & index ) const**

        This pure abstract function must be reimplemented if you want to provide
        custom rendering. The options are specified by **option** and the model
        item by **index**.

        If you reimplement this you must also reimplement **paint** ().
        """
        ...

    def paint(
        self,
        painter: QtGui.QPainter,
        option: "QStyleOptionViewItem",
        index: QtCore.QModelIndex,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemdelegate.html#paint

        **[pure virtual] void QAbstractItemDelegate::paint(QPainter * painter ,
        const QStyleOptionViewItem & option , const QModelIndex & index )
        const**

        This pure abstract function must be reimplemented if you want to provide
        custom rendering. Use the **painter** and style **option** to render the
        item specified by the item **index**.

        If you reimplement this you must also reimplement **sizeHint** ().
        """
        ...

    @property
    def closeEditor(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractitemdelegate.html#closeEditor

        **[signal] void QAbstractItemDelegate::closeEditor(QWidget * editor ,
        QAbstractItemDelegate::EndEditHint hint = NoHint)**

        This signal is emitted when the user has finished editing an item using
        the specified **editor**.

        The **hint** provides a way for the delegate to influence how the model
        and view behave after editing is completed. It indicates to these
        components what action should be performed next to provide a comfortable
        editing experience for the user. For example, if `EditNextItem` is
        specified, the view should use a delegate to open an editor on the next
        item in the model.

        **See also** **EndEditHint** .
        """
        ...

    @property
    def commitData(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractitemdelegate.html#commitData

        **[signal] void QAbstractItemDelegate::commitData(QWidget * editor )**

        This signal must be emitted when the **editor** widget has completed
        editing the data, and wants to write it back into the model.
        """
        ...

    @property
    def sizeHintChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractitemdelegate.html#sizeHintChanged

        **[signal] void QAbstractItemDelegate::sizeHintChanged(const QModelIndex
        & index )**

        This signal must be emitted when the **sizeHint** () of **index**
        changed.

        Views automatically connect to this signal and relayout items as
        necessary.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtQuick import *
import enum


class QSGSimpleTextureNode(QSGGeometryNode):
    """
    https://doc.qt.io/qt-6/qsgsimpletexturenode.html

    **Detailed Description**

    **Warning:** The simple texture node class must have a texture before being
    added to the scene graph to be rendered.

    **Warning:** This utility class is only functional when running with the
    default or software backends of the Qt Quick scenegraph. As an alternative,
    prefer using **QSGImageNode**  via **QQuickWindow::createImageNode** ().
    However, this standalone class is still useful when used via subclassing and
    the application knows that no special scenegraph backends will be involved.
    """

    class TextureCoordinatesTransformFlag(enum.Flag):
        NoTransform: QSGSimpleTextureNode = ...
        MirrorHorizontally: QSGSimpleTextureNode = ...
        MirrorVertically: QSGSimpleTextureNode = ...

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qsgsimpletexturenode.html#QSGSimpleTextureNode

        **QSGSimpleTextureNode::QSGSimpleTextureNode()**

        Constructs a new simple texture node
        """
        ...

    def sourceRect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qsgsimpletexturenode.html#sourceRect

        **[since 5.5] QRectF QSGSimpleTextureNode::sourceRect() const**

        Returns the source rect of this texture node.

        This function was introduced in Qt 5.5.

        **See also** **setSourceRect** ().
        """
        ...

    @typing.overload
    def setSourceRect(self, r: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qsgsimpletexturenode.html#setSourceRect

        **[since 5.5] void QSGSimpleTextureNode::setSourceRect(const QRectF & r
        )**

        Sets the source rect of this texture node to **r**.

        This function was introduced in Qt 5.5.

        **See also** **sourceRect** ().
        """
        ...

    @typing.overload
    def setSourceRect(self, x: float, y: float, w: float, h: float) -> None:
        """
        https://doc.qt.io/qt-6/qsgsimpletexturenode.html#setSourceRect-1

        **[since 5.5] void QSGSimpleTextureNode::setSourceRect(qreal x , qreal y
        , qreal w , qreal h )**

        This is an overloaded function.

        Sets the rectangle of this texture node to show its texture from ( **x**
        , **y** ) and have width **w** and height **h** relatively to the
        **QSGTexture::textureSize** .

        This function was introduced in Qt 5.5.
        """
        ...

    def ownsTexture(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsgsimpletexturenode.html#ownsTexture

        **[since 5.4] bool QSGSimpleTextureNode::ownsTexture() const**

        Returns `true` if the node takes ownership of the texture; otherwise
        returns `false`.

        This function was introduced in Qt 5.4.

        **See also** **setOwnsTexture** ().
        """
        ...

    def setOwnsTexture(self, owns: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsgsimpletexturenode.html#setOwnsTexture

        **[since 5.4] void QSGSimpleTextureNode::setOwnsTexture(bool owns )**

        Sets whether the node takes ownership of the texture to **owns**.

        By default, the node does not take ownership of the texture.

        This function was introduced in Qt 5.4.

        **See also** **ownsTexture** () and **setTexture** ().
        """
        ...

    def textureCoordinatesTransform(
        self,
    ) -> "QSGSimpleTextureNode.TextureCoordinatesTransformFlag":
        """
        https://doc.qt.io/qt-6/qsgsimpletexturenode.html#textureCoordinatesTrans
        form

        **QSGSimpleTextureNode::TextureCoordinatesTransformMode
        QSGSimpleTextureNode::textureCoordinatesTransform() const**

        Returns the mode used to generate texture coordinates for this node.

        **See also** **setTextureCoordinatesTransform** ().
        """
        ...

    def setTextureCoordinatesTransform(
        self, mode: "QSGSimpleTextureNode.TextureCoordinatesTransformFlag"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsgsimpletexturenode.html#setTextureCoordinatesTr
        ansform

        **void QSGSimpleTextureNode::setTextureCoordinatesTransform(QSGSimpleTex
        tureNode::TextureCoordinatesTransformMode mode )**

        Sets the method used to generate texture coordinates to **mode**. This
        can be used to obtain correct orientation of the texture. This is
        commonly needed when using a third party OpenGL library to render to
        texture as OpenGL has an inverted y-axis relative to Qt Quick.

        **See also** **textureCoordinatesTransform** ().
        """
        ...

    def filtering(self) -> "QSGTexture.Filtering":
        """
        https://doc.qt.io/qt-6/qsgsimpletexturenode.html#filtering

        **QSGTexture::Filtering QSGSimpleTextureNode::filtering() const**

        Returns the filtering currently set on this texture node

        **See also** **setFiltering** ().
        """
        ...

    def setFiltering(self, filtering: "QSGTexture.Filtering") -> None:
        """
        https://doc.qt.io/qt-6/qsgsimpletexturenode.html#setFiltering

        **void QSGSimpleTextureNode::setFiltering(QSGTexture::Filtering
        filtering )**

        Sets the filtering to be used for this texture node to **filtering**.

        For smooth scaling, use **QSGTexture::Linear** ; for normal scaling, use
        **QSGTexture::Nearest** .

        **See also** **filtering** ().
        """
        ...

    def texture(self) -> "QSGTexture":
        """
        https://doc.qt.io/qt-6/qsgsimpletexturenode.html#texture

        **QSGTexture *QSGSimpleTextureNode::texture() const**

        Returns the texture for this texture node

        **See also** **setTexture** ().
        """
        ...

    def setTexture(self, texture: "QSGTexture") -> None:
        """
        https://doc.qt.io/qt-6/qsgsimpletexturenode.html#setTexture

        **void QSGSimpleTextureNode::setTexture(QSGTexture * texture )**

        Sets the texture of this texture node to **texture**.

        Use **setOwnsTexture** () to set whether the node should take ownership
        of the texture. By default, the node does not take ownership.

        **Warning:** A texture node must have a texture before being added to
        the scenegraph to be rendered.

        **See also** **texture** ().
        """
        ...

    def rect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qsgsimpletexturenode.html#rect

        **QRectF QSGSimpleTextureNode::rect() const**

        Returns the target rect of this texture node.

        **See also** **setRect** ().
        """
        ...

    @typing.overload
    def setRect(self, rect: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qsgsimpletexturenode.html#setRect

        **void QSGSimpleTextureNode::setRect(const QRectF & r )**

        Sets the target rect of this texture node to **r**.

        **See also** **rect** ().
        """
        ...

    @typing.overload
    def setRect(self, x: float, y: float, w: float, h: float) -> None:
        """
        https://doc.qt.io/qt-6/qsgsimpletexturenode.html#setRect-1

        **void QSGSimpleTextureNode::setRect(qreal x , qreal y , qreal w , qreal
        h )**

        This is an overloaded function.

        Sets the rectangle of this texture node to begin at ( **x** , **y** )
        and have width **w** and height **h**.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtMultimedia import *


class QCameraFormat(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qcameraformat.html

    **Detailed Description**

    QCameraFormat represents a certain video format supported by a camera
    device.

    The format is a combination of a **pixel format** , resolution and a range
    of frame rates.

    QCameraFormat objects can be queried from **QCameraDevice**  to inspect the
    set of supported video formats.

    **See also** **QCameraDevice**  and **QCamera** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qcameraformat.html#QCameraFormat

        **QCameraFormat::QCameraFormat()**

        Constructs a null camera format.

        **See also** **isNull** ().
        """
        ...

    @typing.overload
    def __init__(self, other: "QCameraFormat") -> None:
        """
        https://doc.qt.io/qt-6/qcameraformat.html#QCameraFormat-1

        **QCameraFormat::QCameraFormat(const QCameraFormat & other )**

        Copy constructs a camera format from the **other** format.
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcameraformat.html#isNull

        **bool QCameraFormat::isNull() const**

        Returns true if this is a default constructed **QCameraFormat** .
        """
        ...

    def maxFrameRate(self) -> float:
        """
        https://doc.qt.io/qt-6/qcameraformat.html#maxFrameRate

        **float QCameraFormat::maxFrameRate() const**

        Returns the highest frame rate defined by this format.

        In 6.2, the camera will always try to use the highest frame rate
        supported by a certain video format.

        **Note:** Getter function for property maxFrameRate.
        """
        ...

    def minFrameRate(self) -> float:
        """
        https://doc.qt.io/qt-6/qcameraformat.html#minFrameRate

        **float QCameraFormat::minFrameRate() const**

        Returns the lowest frame rate defined by this format.

        **Note:** Getter function for property minFrameRate.
        """
        ...

    def resolution(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qcameraformat.html#resolution

        **QSize QCameraFormat::resolution() const**

        Returns the resolution.

        **Note:** Getter function for property resolution.
        """
        ...

    def pixelFormat(self) -> "QVideoFrameFormat.PixelFormat":
        """
        https://doc.qt.io/qt-6/qcameraformat.html#pixelFormat

        **QVideoFrameFormat::PixelFormat QCameraFormat::pixelFormat() const**

        Returns the pixel format.

        Most commonly this is either **QVideoFrameFormat::Format_Jpeg**  or
        QVideoFrameFormat::Format_YUVY but other formats could also be supported
        by the camera.

        **Note:** Getter function for property pixelFormat.

        **See also** **QVideoFrameFormat::PixelFormat** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtRemoteObjects import *
import enum


class QRemoteObjectReplica(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qremoteobjectreplica.html

    **Detailed Description**

    A Remote Object Replica is a **QObject**  proxy for another **QObject**
    (called the **Source**  object). Once initialized, a replica can be
    considered a "latent copy" of the **Source**  object. That is, every change
    to a **Q_PROPERTY**  on the **Source** , or signal emitted by the **Source**
    will be updated/emitted by all **Replica**  objects. Latency is introduced
    by process scheduling by any OSes involved and network communication
    latency. As long as the replica has been initialized and the communication
    is not disrupted, receipt and order of changes is guaranteed.

    The **isInitialized**  and **state**  properties (and corresponding
    **initialized** ()/**stateChanged** () signals) allow the state of a
    **Replica**  to be determined.

    While Qt Remote Objects (QtRO) handles the initialization and
    synchronization of **Replica**  objects, there are numerous steps happening
    behind the scenes which can fail and that aren't encountered in single
    process Qt applications. See **Troubleshooting**  for advice on how to
    handle such issues when using a remote objects network.
    """

    class State(enum.Enum):
        Uninitialized: QRemoteObjectReplica = ...
        Default: QRemoteObjectReplica = ...
        Valid: QRemoteObjectReplica = ...
        Suspect: QRemoteObjectReplica = ...
        SignatureMismatch: QRemoteObjectReplica = ...

    def setNode(self, node: "QRemoteObjectNode") -> None:
        """
        https://doc.qt.io/qt-6/qremoteobjectreplica.html#node-prop

        **node : QRemoteObjectNode***

        This property holds a pointer to the node this object was acquired from.

        **Access functions:**

        QRemoteObjectNode * **node** () const
        virtual void **setNode**
        (QRemoteObjectNode * **node** )
        """
        ...

    def node(self) -> "QRemoteObjectNode":
        """
        https://doc.qt.io/qt-6/qremoteobjectreplica.html#node-prop

        **node : QRemoteObjectNode***

        This property holds a pointer to the node this object was acquired from.

        **Access functions:**

        QRemoteObjectNode * **node** () const
        virtual void **setNode**
        (QRemoteObjectNode * **node** )
        """
        ...

    def state(self) -> "QRemoteObjectReplica.State":
        """
        https://doc.qt.io/qt-6/qremoteobjectreplica.html#state

        **QRemoteObjectReplica::State QRemoteObjectReplica::state() const**

        Returns `true` if this replica has been initialized with data from the
        **Source**  object. Returns `false` otherwise.

        **Note:** Getter function for property state.

        **See also** **isInitialized** ().
        """
        ...

    def isInitialized(self) -> bool:
        """
        https://doc.qt.io/qt-6/qremoteobjectreplica.html#isInitialized

        **bool QRemoteObjectReplica::isInitialized() const**

        Returns `true` if this replica has been initialized with data from the
        **Source**  object. Returns `false` otherwise.

        **See also** **state** ().
        """
        ...

    def waitForSource(self, timeout: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qremoteobjectreplica.html#waitForSource

        **bool QRemoteObjectReplica::waitForSource(int timeout = 30000)**

        Blocking call that waits for the replica to become initialized or until
        the **timeout** (in ms) expires. Returns `true` if the replica is
        initialized when the call completes, `false` otherwise.

        If **timeout** is -1, this function will not time out.

        **See also** **isInitialized** () and **initialized** ().
        """
        ...

    def isReplicaValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qremoteobjectreplica.html#isReplicaValid

        **bool QRemoteObjectReplica::isReplicaValid() const**

        Returns `true` if this replica has been initialized and has a valid
        connection with the **node**  hosting the **Source** . Returns `false`
        otherwise.

        **See also** **isInitialized** ().
        """
        ...

    @property
    def initialized(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qremoteobjectreplica.html#initialized

        **[signal] void QRemoteObjectReplica::initialized()**

        This signal is emitted once the replica is initialized. An intialized
        replica has all property values set, but has not yet emitted any
        property change notifications.

        **See also** **isInitialized** () and **stateChanged** ().
        """
        ...

    @property
    def notified(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qremoteobjectreplica.html#notified

        **[signal] void QRemoteObjectReplica::notified()**

        This signal is emitted once the replica is initialized and all property
        change notifications have been emitted.

        It is sometimes useful to respond to property changes as events. For
        example, you might want to display a user notification when a certain
        property change occurs. However, this user notification would then also
        be triggered when a replica first became `QRemoteObjectReplica::Valid`,
        as all property change signals are emitted at that time. This isn't
        always desirable, and `notified` allows the developer to distinguish
        between these two cases.
        """
        ...

    @property
    def stateChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qremoteobjectreplica.html#stateChanged

        **[signal] void
        QRemoteObjectReplica::stateChanged(QRemoteObjectReplica::State state ,
        QRemoteObjectReplica::State oldState )**

        This signal is emitted whenever a replica's state toggles between
        **QRemoteObjectReplica::State** .

        The change in state is represented with **state** and **oldState**.

        **Note:** Notifier signal for property **state** .

        **See also** **state** () and **initialized** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from ._functions import PYQT_SIGNAL as PYQT_SIGNAL
from ._functions import PYQT_SLOT as PYQT_SLOT
from ._QSensorReading import QSensorReading as QSensorReading
from ._QAccelerometerReading import QAccelerometerReading as QAccelerometerReading
from ._QSensorFilter import QSensorFilter as QSensorFilter
from ._QAccelerometerFilter import QAccelerometerFilter as QAccelerometerFilter
from ._QSensor import QSensor as QSensor
from ._QAccelerometer import QAccelerometer as QAccelerometer
from ._QAmbientLightReading import QAmbientLightReading as QAmbientLightReading
from ._QAmbientLightFilter import QAmbientLightFilter as QAmbientLightFilter
from ._QAmbientLightSensor import QAmbientLightSensor as QAmbientLightSensor
from ._QAmbientTemperatureReading import (
    QAmbientTemperatureReading as QAmbientTemperatureReading,
)
from ._QAmbientTemperatureFilter import (
    QAmbientTemperatureFilter as QAmbientTemperatureFilter,
)
from ._QAmbientTemperatureSensor import (
    QAmbientTemperatureSensor as QAmbientTemperatureSensor,
)
from ._QCompassReading import QCompassReading as QCompassReading
from ._QCompassFilter import QCompassFilter as QCompassFilter
from ._QCompass import QCompass as QCompass
from ._QGyroscopeReading import QGyroscopeReading as QGyroscopeReading
from ._QGyroscopeFilter import QGyroscopeFilter as QGyroscopeFilter
from ._QGyroscope import QGyroscope as QGyroscope
from ._QHumidityReading import QHumidityReading as QHumidityReading
from ._QHumidityFilter import QHumidityFilter as QHumidityFilter
from ._QHumiditySensor import QHumiditySensor as QHumiditySensor
from ._QIRProximityReading import QIRProximityReading as QIRProximityReading
from ._QIRProximityFilter import QIRProximityFilter as QIRProximityFilter
from ._QIRProximitySensor import QIRProximitySensor as QIRProximitySensor
from ._QLidReading import QLidReading as QLidReading
from ._QLidFilter import QLidFilter as QLidFilter
from ._QLidSensor import QLidSensor as QLidSensor
from ._QLightReading import QLightReading as QLightReading
from ._QLightFilter import QLightFilter as QLightFilter
from ._QLightSensor import QLightSensor as QLightSensor
from ._QMagnetometerReading import QMagnetometerReading as QMagnetometerReading
from ._QMagnetometerFilter import QMagnetometerFilter as QMagnetometerFilter
from ._QMagnetometer import QMagnetometer as QMagnetometer
from ._QOrientationReading import QOrientationReading as QOrientationReading
from ._QOrientationFilter import QOrientationFilter as QOrientationFilter
from ._QOrientationSensor import QOrientationSensor as QOrientationSensor
from ._QPressureReading import QPressureReading as QPressureReading
from ._QPressureFilter import QPressureFilter as QPressureFilter
from ._QPressureSensor import QPressureSensor as QPressureSensor
from ._QProximityReading import QProximityReading as QProximityReading
from ._QProximityFilter import QProximityFilter as QProximityFilter
from ._QProximitySensor import QProximitySensor as QProximitySensor
from ._QRotationReading import QRotationReading as QRotationReading
from ._QRotationFilter import QRotationFilter as QRotationFilter
from ._QRotationSensor import QRotationSensor as QRotationSensor
from ._qoutputrange import qoutputrange as qoutputrange
from ._QTapReading import QTapReading as QTapReading
from ._QTapFilter import QTapFilter as QTapFilter
from ._QTapSensor import QTapSensor as QTapSensor
from ._QTiltReading import QTiltReading as QTiltReading
from ._QTiltFilter import QTiltFilter as QTiltFilter
from ._QTiltSensor import QTiltSensor as QTiltSensor



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QPageLayout(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qpagelayout.html

    **Detailed Description**

    The QPageLayout class defines the layout of a page in a paged document, with
    the page size, orientation and margins able to be set and the full page and
    paintable page rectangles defined by those attributes able to be queried in
    a variety of units.

    The page size is defined by the **QPageSize**  class which can be queried
    for page size attributes. Note that the **QPageSize**  itself is always
    defined in a Portrait orientation.

    The minimum margins can be defined for the layout but normally default to 0.
    When used in conjunction with Qt's printing support the minimum margins will
    reflect the minimum printable area defined by the printer.

    In the default **StandardMode**  the current margins and minimum margins are
    always taken into account. The paintable rectangle is the full page
    rectangle less the current margins, and the current margins can only be set
    to values between the minimum margins and the maximum margins allowed by the
    full page size.

    In **FullPageMode**  the current margins and minimum margins are not taken
    into account. The paintable rectangle is the full page rectangle, and the
    current margins can be set to any values regardless of the minimum margins
    and page size.

    **See also** **QPageSize** .
    """

    class Mode(enum.Enum):
        StandardMode: QPageLayout = ...
        FullPageMode: QPageLayout = ...

    class Orientation(enum.Enum):
        Portrait: QPageLayout = ...
        Landscape: QPageLayout = ...

    class Unit(enum.Enum):
        Millimeter: QPageLayout = ...
        Point: QPageLayout = ...
        Inch: QPageLayout = ...
        Pica: QPageLayout = ...
        Didot: QPageLayout = ...
        Cicero: QPageLayout = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#QPageLayout

        **QPageLayout::QPageLayout()**

        Creates an invalid QPageLayout.
        """
        ...

    @typing.overload
    def __init__(
        self,
        pageSize: "QPageSize",
        orientation: "QPageLayout.Orientation",
        margins: QtCore.QMarginsF,
        units: "QPageLayout.Unit" = ...,
        minMargins: QtCore.QMarginsF = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#QPageLayout-1

        **QPageLayout::QPageLayout(const QPageSize & pageSize ,
        QPageLayout::Orientation orientation , const QMarginsF & margins ,
        QPageLayout::Unit units = Point, const QMarginsF & minMargins =
        QMarginsF(0, 0, 0, 0))**

        Creates a QPageLayout with the given **pageSize** , **orientation** and
        **margins** in the given **units**.

        Optionally define the minimum allowed margins **minMargins** , e.g. the
        minimum margins able to be printed by a physical print device.

        The constructed QPageLayout will be in **StandardMode** .

        The **margins** given will be clamped to the minimum margins and the
        maximum margins allowed by the page size.
        """
        ...

    @typing.overload
    def __init__(self, other: "QPageLayout") -> None:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#QPageLayout-2

        **QPageLayout::QPageLayout(const QPageLayout & other )**

        Copy constructor, copies **other** to this.
        """
        ...

    def paintRectPixels(self, resolution: int) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#paintRectPixels

        **QRect QPageLayout::paintRectPixels(int resolution ) const**

        Returns the paintable rectangle in rounded device pixels for the given
        **resolution**.

        The paintable rectangle takes into account the page size, orientation
        and margins.

        If the **FullPageMode**  mode is set then the **fullRect** () is
        returned and the margins must be manually managed.
        """
        ...

    def paintRectPoints(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#paintRectPoints

        **QRect QPageLayout::paintRectPoints() const**

        Returns the paintable rectangle in rounded Postscript Points (1/72 of an
        inch).

        The paintable rectangle takes into account the page size, orientation
        and margins.

        If the **FullPageMode**  mode is set then the **fullRect** () is
        returned and the margins must be manually managed.
        """
        ...

    @typing.overload
    def paintRect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#paintRect

        **QRectF QPageLayout::paintRect() const**

        Returns the page rectangle in the current layout units.

        The paintable rectangle takes into account the page size, orientation
        and margins.

        If the **FullPageMode**  mode is set then the **fullRect** () is
        returned and the margins must be manually managed.
        """
        ...

    @typing.overload
    def paintRect(self, units: "QPageLayout.Unit") -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#paintRect-1

        **QRectF QPageLayout::paintRect(QPageLayout::Unit units ) const**

        Returns the page rectangle in the required **units**.

        The paintable rectangle takes into account the page size, orientation
        and margins.

        If the **FullPageMode**  mode is set then the **fullRect** () is
        returned and the margins must be manually managed.
        """
        ...

    def fullRectPixels(self, resolution: int) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#fullRectPixels

        **QRect QPageLayout::fullRectPixels(int resolution ) const**

        Returns the full page rectangle in device pixels for the given
        **resolution**.

        The page rectangle takes into account the page size and page
        orientation, but not the page margins.

        **See also** **paintRect** ().
        """
        ...

    def fullRectPoints(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#fullRectPoints

        **QRect QPageLayout::fullRectPoints() const**

        Returns the full page rectangle in Postscript Points (1/72 of an inch).

        The page rectangle takes into account the page size and page
        orientation, but not the page margins.

        **See also** **paintRect** ().
        """
        ...

    @typing.overload
    def fullRect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#fullRect

        **QRectF QPageLayout::fullRect() const**

        Returns the full page rectangle in the current layout units.

        The page rectangle takes into account the page size and page
        orientation, but not the page margins.

        **See also** **paintRect** () and **units** ().
        """
        ...

    @typing.overload
    def fullRect(self, units: "QPageLayout.Unit") -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#fullRect-1

        **QRectF QPageLayout::fullRect(QPageLayout::Unit units ) const**

        Returns the full page rectangle in the required **units**.

        The page rectangle takes into account the page size and page
        orientation, but not the page margins.

        **See also** **paintRect** ().
        """
        ...

    def maximumMargins(self) -> QtCore.QMarginsF:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#maximumMargins

        **QMarginsF QPageLayout::maximumMargins() const**

        Returns the maximum margins that would be applied if the page layout was
        in **StandardMode** .

        The maximum margins allowed are calculated as the full size of the page
        minus the minimum margins set. For example, if the page width is 100
        points and the minimum right margin is 10 points, then the maximum left
        margin will be 90 points.

        **See also** **setMinimumMargins** () and **minimumMargins** ().
        """
        ...

    def minimumMargins(self) -> QtCore.QMarginsF:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#minimumMargins

        **QMarginsF QPageLayout::minimumMargins() const**

        Returns the minimum margins of the page layout.

        **See also** **setMinimumMargins** () and **maximumMargins** ().
        """
        ...

    def setMinimumMargins(self, minMargins: QtCore.QMarginsF) -> None:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#setMinimumMargins

        **void QPageLayout::setMinimumMargins(const QMarginsF & minMargins )**

        Sets the minimum page margins of the page layout to **minMargins**.

        It is not recommended to override the default values set for a page size
        as this may be the minimum printable area for a physical print device.

        If the **StandardMode**  mode is set then the existing margins will be
        clamped to the new **minMargins** and the maximum allowed by the page
        size. If the **FullPageMode**  is set then the existing margins will be
        unchanged.

        **See also** **minimumMargins** () and **setMargins** ().
        """
        ...

    def marginsPixels(self, resolution: int) -> QtCore.QMargins:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#marginsPixels

        **QMargins QPageLayout::marginsPixels(int resolution ) const**

        Returns the margins of the page layout in device pixels for the given
        **resolution**.

        **See also** **setMargins** ().
        """
        ...

    def marginsPoints(self) -> QtCore.QMargins:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#marginsPoints

        **QMargins QPageLayout::marginsPoints() const**

        Returns the margins of the page layout in Postscript Points (1/72 of an
        inch).

        **See also** **setMargins** () and **margins** ().
        """
        ...

    @typing.overload
    def margins(self) -> QtCore.QMarginsF:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#margins

        **QMarginsF QPageLayout::margins() const**

        Returns the margins of the page layout using the currently set units.

        **See also** **setMargins** () and **units** ().
        """
        ...

    @typing.overload
    def margins(self, units: "QPageLayout.Unit") -> QtCore.QMarginsF:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#margins-1

        **QMarginsF QPageLayout::margins(QPageLayout::Unit units ) const**

        Returns the margins of the page layout using the requested **units**.

        **See also** **setMargins** () and **margins** ().
        """
        ...

    def setBottomMargin(self, bottomMargin: float) -> bool:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#setBottomMargin

        **bool QPageLayout::setBottomMargin(qreal bottomMargin )**

        Sets the bottom page margin of the page layout to **bottomMargin**.
        Returns true if the margin was successfully set.

        The units used are those currently defined for the layout. To use
        different units call **setUnits** () first.

        If in the default **StandardMode**  then the new margin must fall
        between the minimum margin set and the maximum margin allowed by the
        page size, otherwise the margin will not be set.

        If in **FullPageMode**  then any margin values will be accepted.

        **See also** **setMargins** () and **margins** ().
        """
        ...

    def setTopMargin(self, topMargin: float) -> bool:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#setTopMargin

        **bool QPageLayout::setTopMargin(qreal topMargin )**

        Sets the top page margin of the page layout to **topMargin**. Returns
        true if the margin was successfully set.

        The units used are those currently defined for the layout. To use
        different units call **setUnits** () first.

        If in the default **StandardMode**  then the new margin must fall
        between the minimum margin set and the maximum margin allowed by the
        page size, otherwise the margin will not be set.

        If in **FullPageMode**  then any margin values will be accepted.

        **See also** **setMargins** () and **margins** ().
        """
        ...

    def setRightMargin(self, rightMargin: float) -> bool:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#setRightMargin

        **bool QPageLayout::setRightMargin(qreal rightMargin )**

        Sets the right page margin of the page layout to **rightMargin**.
        Returns true if the margin was successfully set.

        The units used are those currently defined for the layout. To use
        different units call **setUnits** () first.

        If in the default **StandardMode**  then the new margin must fall
        between the minimum margin set and the maximum margin allowed by the
        page size, otherwise the margin will not be set.

        If in **FullPageMode**  then any margin values will be accepted.

        **See also** **setMargins** () and **margins** ().
        """
        ...

    def setLeftMargin(self, leftMargin: float) -> bool:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#setLeftMargin

        **bool QPageLayout::setLeftMargin(qreal leftMargin )**

        Sets the left page margin of the page layout to **leftMargin**. Returns
        true if the margin was successfully set.

        The units used are those currently defined for the layout. To use
        different units call **setUnits** () first.

        If in the default **StandardMode**  then the new margin must fall
        between the minimum margin set and the maximum margin allowed by the
        page size, otherwise the margin will not be set.

        If in **FullPageMode**  then any margin values will be accepted.

        **See also** **setMargins** () and **margins** ().
        """
        ...

    def setMargins(self, margins: QtCore.QMarginsF) -> bool:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#setMargins

        **bool QPageLayout::setMargins(const QMarginsF & margins )**

        Sets the page margins of the page layout to **margins** Returns true if
        the margins were successfully set.

        The units used are those currently defined for the layout. To use
        different units then call **setUnits** () first.

        If in the default **StandardMode**  then all the new margins must fall
        between the minimum margins set and the maximum margins allowed by the
        page size, otherwise the margins will not be set.

        If in **FullPageMode**  then any margin values will be accepted.

        **See also** **margins** () and **units** ().
        """
        ...

    def units(self) -> "QPageLayout.Unit":
        """
        https://doc.qt.io/qt-6/qpagelayout.html#units

        **QPageLayout::Unit QPageLayout::units() const**

        Returns the units the page layout is currently defined in.

        **See also** **setUnits** ().
        """
        ...

    def setUnits(self, units: "QPageLayout.Unit") -> None:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#setUnits

        **void QPageLayout::setUnits(QPageLayout::Unit units )**

        Sets the **units** used to define the page layout.

        **See also** **units** ().
        """
        ...

    def orientation(self) -> "QPageLayout.Orientation":
        """
        https://doc.qt.io/qt-6/qpagelayout.html#orientation

        **QPageLayout::Orientation QPageLayout::orientation() const**

        Returns the page orientation of the page layout.

        **See also** **setOrientation** ().
        """
        ...

    def setOrientation(self, orientation: "QPageLayout.Orientation") -> None:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#setOrientation

        **void QPageLayout::setOrientation(QPageLayout::Orientation orientation
        )**

        Sets the page orientation of the page layout to **orientation**.

        Changing the orientation does not affect the current margins or the
        minimum margins.

        **See also** **orientation** ().
        """
        ...

    def pageSize(self) -> "QPageSize":
        """
        https://doc.qt.io/qt-6/qpagelayout.html#pageSize

        **QPageSize QPageLayout::pageSize() const**

        Returns the page size of the page layout.

        Note that the **QPageSize**  is always defined in a Portrait
        orientation. To obtain a size that takes the set orientation into
        account you must use **fullRect** ().

        **See also** **setPageSize** ().
        """
        ...

    def setPageSize(
        self, pageSize: "QPageSize", minMargins: QtCore.QMarginsF = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#setPageSize

        **void QPageLayout::setPageSize(const QPageSize & pageSize , const
        QMarginsF & minMargins = QMarginsF(0, 0, 0, 0))**

        Sets the page size of the page layout to **pageSize**.

        Optionally define the minimum allowed margins **minMargins** , e.g. the
        minimum margins able to be printed by a physical print device, otherwise
        the minimum margins will default to 0.

        If **StandardMode**  is set then the existing margins will be clamped to
        the new minimum margins and the maximum margins allowed by the page
        size. If **FullPageMode**  is set then the existing margins will be
        unchanged.

        **See also** **pageSize** ().
        """
        ...

    def mode(self) -> "QPageLayout.Mode":
        """
        https://doc.qt.io/qt-6/qpagelayout.html#mode

        **QPageLayout::Mode QPageLayout::mode() const**

        Returns the page layout mode.

        **See also** **setMode** ().
        """
        ...

    def setMode(self, mode: "QPageLayout.Mode") -> None:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#setMode

        **void QPageLayout::setMode(QPageLayout::Mode mode )**

        Sets a page layout mode to **mode**.

        **See also** **mode** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#isValid

        **bool QPageLayout::isValid() const**

        Returns `true` if this page layout is valid.
        """
        ...

    def isEquivalentTo(self, other: "QPageLayout") -> bool:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#isEquivalentTo

        **bool QPageLayout::isEquivalentTo(const QPageLayout & other ) const**

        Returns `true` if this page layout is equivalent to the **other** page
        layout, i.e. if the page has the same size, margins and orientation.
        """
        ...

    def swap(self, other: "QPageLayout") -> None:
        """
        https://doc.qt.io/qt-6/qpagelayout.html#swap

        **void QPageLayout::swap(QPageLayout & other )**

        Swaps this page layout with **other**. This function is very fast and
        never fails.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QStandardItemModel(QtCore.QAbstractItemModel):
    """
    https://doc.qt.io/qt-6/qstandarditemmodel.html

    **Detailed Description**

    QStandardItemModel can be used as a repository for standard Qt data types.
    It is one of the **Model/View Classes**  and is part of Qt's **model/view**
    framework.

    QStandardItemModel provides a classic item-based approach to working with
    the model. The items in a QStandardItemModel are provided by
    **QStandardItem** .

    QStandardItemModel implements the **QAbstractItemModel**  interface, which
    means that the model can be used to provide data in any view that supports
    that interface (such as **QListView** , **QTableView**  and **QTreeView** ,
    and your own custom views). For performance and flexibility, you may want to
    subclass **QAbstractItemModel**  to provide support for different kinds of
    data repositories. For example, the **QFileSystemModel**  provides a model
    interface to the underlying file system.

    When you want a list or tree, you typically create an empty
    QStandardItemModel and use **appendRow** () to add items to the model, and
    **item** () to access an item. If your model represents a table, you
    typically pass the dimensions of the table to the QStandardItemModel
    constructor and use **setItem** () to position items into the table. You can
    also use **setRowCount** () and **setColumnCount** () to alter the
    dimensions of the model. To insert items, use **insertRow** () or
    **insertColumn** (), and to remove items, use **removeRow** () or
    **removeColumn** ().

    You can set the header labels of your model with
    **setHorizontalHeaderLabels** () and **setVerticalHeaderLabels** ().

    You can search for items in the model with **findItems** (), and sort the
    model by calling **sort** ().

    Call **clear** () to remove all items from the model.

    An example usage of QStandardItemModel to create a table:

    **QStandardItemModel**  model(4, 4);
        for (int row = 0; row <
    model.rowCount(); ++row) {
            for (int column = 0; column <
    model.columnCount(); ++column) {
                **QStandardItem**  *item = new
    **QStandardItem** (**QString** ("row %0, column %1").arg(row).arg(column));
    model.setItem(row, column, item);
            }
        }

    An example usage of QStandardItemModel to create a tree:

    **QStandardItemModel**  model;
        **QStandardItem**  *parentItem =
    model.invisibleRootItem();
        for (int i = 0; i < 4; ++i) {
    **QStandardItem**  *item = new **QStandardItem** (**QString** ("item
    %0").arg(i));
            parentItem->appendRow(item);
            parentItem =
    item;
        }

    After setting the model on a view, you typically want to react to user
    actions, such as an item being clicked. Since a **QAbstractItemView**
    provides **QModelIndex** -based signals and functions, you need a way to
    obtain the **QStandardItem**  that corresponds to a given **QModelIndex** ,
    and vice versa. **itemFromIndex** () and **indexFromItem** () provide this
    mapping. Typical usage of **itemFromIndex** () includes obtaining the item
    at the current index in a view, and obtaining the item that corresponds to
    an index carried by a **QAbstractItemView**  signal, such as
    **QAbstractItemView::clicked** (). First you connect the view's signal to a
    slot in your class:

    **QTreeView**  *treeView = new **QTreeView** (this);
    treeView->setModel(myStandardItemModel);
        connect(treeView,
    &**QTreeView** ::clicked,
                this, &MyWidget::clicked);

    When you receive the signal, you call **itemFromIndex** () on the given
    model index to get a pointer to the item:

    void MyWidget::clicked(const **QModelIndex**  &index)
        {
    **QStandardItem**  *item = myStandardItemModel->itemFromIndex(index);
    // Do stuff with the item ...
        }

    Conversely, you must obtain the **QModelIndex**  of an item when you want to
    invoke a model/view function that takes an index as argument. You can obtain
    the index either by using the model's **indexFromItem** () function, or,
    equivalently, by calling **QStandardItem::index** ():

    treeView->scrollTo(item->index());

    You are, of course, not required to use the item-based approach; you could
    instead rely entirely on the **QAbstractItemModel**  interface when working
    with the model, or use a combination of the two as appropriate.

    **See also** **QStandardItem** , **Model/View Programming** ,
    **QAbstractItemModel** , **Simple Tree Model example** , and **Item View
    Convenience Classes** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#QStandardItemModel

        **QStandardItemModel::QStandardItemModel(QObject * parent = nullptr)**

        Constructs a new item model with the given **parent**.
        """
        ...

    @typing.overload
    def __init__(
        self, rows: int, columns: int, parent: typing.Optional[QtCore.QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#QStandardItemModel-1

        **QStandardItemModel::QStandardItemModel(int rows , int columns ,
        QObject * parent = nullptr)**

        Constructs a new item model that initially has **rows** rows and
        **columns** columns, and that has the given **parent**.
        """
        ...

    def roleNames(self) -> typing.Dict[int, QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#roleNames

        **[override virtual] QHash<int, QByteArray>
        QStandardItemModel::roleNames() const**

        Reimplements: **QAbstractItemModel::roleNames() const** .

        reimp
        """
        ...

    def clearItemData(self, index: QtCore.QModelIndex) -> bool:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#clearItemData

        **[override virtual] bool QStandardItemModel::clearItemData(const
        QModelIndex & index )**

        Reimplements: **QAbstractItemModel::clearItemData** (const QModelIndex
        &index).
        """
        ...

    def setItemRoleNames(self, roleNames: typing.Dict[int, QtCore.QByteArray]) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#setItemRoleNames

        **void QStandardItemModel::setItemRoleNames(const QHash<int, QByteArray>
        & roleNames )**

        Sets the item role names to **roleNames**.
        """
        ...

    def dropMimeData(
        self,
        data: QtCore.QMimeData,
        action: QtCore.Qt.DropAction,
        row: int,
        column: int,
        parent: QtCore.QModelIndex,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#dropMimeData

        **[override virtual] bool QStandardItemModel::dropMimeData(const
        QMimeData * data , Qt::DropAction action , int row , int column , const
        QModelIndex & parent )**

        Reimplements: **QAbstractItemModel::dropMimeData** (const QMimeData
        *data, Qt::DropAction action, int row, int column, const QModelIndex
        &parent).
        """
        ...

    def mimeData(
        self, indexes: typing.Iterable[QtCore.QModelIndex]
    ) -> QtCore.QMimeData:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#mimeData

        **[override virtual] QMimeData *QStandardItemModel::mimeData(const
        QModelIndexList & indexes ) const**

        Reimplements: **QAbstractItemModel::mimeData(const QModelIndexList
        &indexes) const** .
        """
        ...

    def mimeTypes(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#mimeTypes

        **[override virtual] QStringList QStandardItemModel::mimeTypes() const**

        Reimplements: **QAbstractItemModel::mimeTypes() const** .
        """
        ...

    def setSortRole(self, role: int) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#sortRole-prop

        **[bindable] sortRole : int**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the item role that is used to query the model's data
        when sorting items

        The default value is **Qt::DisplayRole** .

        **See also** **sort** () and **QStandardItem::sortChildren** ().

        **Member Function Documentation**
        """
        ...

    def sortRole(self) -> int:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#sortRole-prop

        **[bindable] sortRole : int**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the item role that is used to query the model's data
        when sorting items

        The default value is **Qt::DisplayRole** .

        **See also** **sort** () and **QStandardItem::sortChildren** ().

        **Member Function Documentation**
        """
        ...

    def findItems(
        self, text: str, flags: QtCore.Qt.MatchFlag = ..., column: int = ...
    ) -> typing.List["QStandardItem"]:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#findItems

        **QList<QStandardItem *> QStandardItemModel::findItems(const QString &
        text , Qt::MatchFlags flags = Qt::MatchExactly, int column = 0) const**

        Returns a list of items that match the given **text** , using the given
        **flags** , in the given **column**.
        """
        ...

    def setItemPrototype(self, item: "QStandardItem") -> None:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#setItemPrototype

        **void QStandardItemModel::setItemPrototype(const QStandardItem * item
        )**

        Sets the item prototype for the model to the specified **item**. The
        model takes ownership of the prototype.

        The item prototype acts as a **QStandardItem**  factory, by relying on
        the **QStandardItem::clone** () function. To provide your own prototype,
        subclass **QStandardItem** , reimplement **QStandardItem::clone** () and
        set the prototype to be an instance of your custom class. Whenever
        **QStandardItemModel**  needs to create an item on demand (for instance,
        when a view or item delegate calls **setData** ())), the new items will
        be instances of your custom class.

        **See also** **itemPrototype** () and **QStandardItem::clone** ().
        """
        ...

    def itemPrototype(self) -> "QStandardItem":
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#itemPrototype

        **const QStandardItem *QStandardItemModel::itemPrototype() const**

        Returns the item prototype used by the model. The model uses the item
        prototype as an item factory when it needs to construct new items on
        demand (for instance, when a view or item delegate calls **setData**
        ()).

        **See also** **setItemPrototype** ().
        """
        ...

    def takeVerticalHeaderItem(self, row: int) -> "QStandardItem":
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#takeVerticalHeaderItem

        **QStandardItem *QStandardItemModel::takeVerticalHeaderItem(int row )**

        Removes the vertical header item at **row** from the header without
        deleting it, and returns a pointer to the item. The model releases
        ownership of the item.

        **See also** **verticalHeaderItem** () and **takeHorizontalHeaderItem**
        ().
        """
        ...

    def takeHorizontalHeaderItem(self, column: int) -> "QStandardItem":
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#takeHorizontalHeaderItem

        **QStandardItem *QStandardItemModel::takeHorizontalHeaderItem(int column
        )**

        Removes the horizontal header item at **column** from the header without
        deleting it, and returns a pointer to the item. The model releases
        ownership of the item.

        **See also** **horizontalHeaderItem** () and **takeVerticalHeaderItem**
        ().
        """
        ...

    def takeColumn(self, column: int) -> typing.List["QStandardItem"]:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#takeColumn

        **QList<QStandardItem *> QStandardItemModel::takeColumn(int column )**

        Removes the given **column** without deleting the column items, and
        returns a list of pointers to the removed items. The model releases
        ownership of the items. For items in the column that have not been set,
        the corresponding pointers in the list will be `nullptr`.

        **See also** **takeRow** ().
        """
        ...

    def takeRow(self, row: int) -> typing.List["QStandardItem"]:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#takeRow

        **QList<QStandardItem *> QStandardItemModel::takeRow(int row )**

        Removes the given **row** without deleting the row items, and returns a
        list of pointers to the removed items. The model releases ownership of
        the items. For items in the row that have not been set, the
        corresponding pointers in the list will be `nullptr`.

        **See also** **takeColumn** ().
        """
        ...

    def takeItem(self, row: int, column: int = ...) -> "QStandardItem":
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#takeItem

        **QStandardItem *QStandardItemModel::takeItem(int row , int column =
        0)**

        Removes the item at ( **row** , **column** ) without deleting it. The
        model releases ownership of the item.

        **See also** **item** (), **takeRow** (), and **takeColumn** ().
        """
        ...

    @typing.overload
    def insertColumn(
        self, column: int, items: typing.Iterable["QStandardItem"]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#insertColumn

        **void QStandardItemModel::insertColumn(int column , const
        QList<QStandardItem *> & items )**

        Inserts a column at **column** containing **items**. If necessary, the
        row count is increased to the size of **items**.

        **See also** **takeColumn** (), **appendColumn** (), and **insertRow**
        ().
        """
        ...

    @typing.overload
    def insertColumn(self, column: int, parent: QtCore.QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#insertColumn-1

        **bool QStandardItemModel::insertColumn(int column , const QModelIndex &
        parent = QModelIndex())**

        Inserts a single column before the given **column** in the child items
        of the **parent** specified. Returns `true` if the column is inserted;
        otherwise returns `false`.

        **See also** **insertColumns** (), **insertRow** (), and
        **removeColumn** ().
        """
        ...

    @typing.overload
    def insertRow(self, row: int, items: typing.Iterable["QStandardItem"]) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#insertRow

        **void QStandardItemModel::insertRow(int row , const QList<QStandardItem
        *> & items )**

        Inserts a row at **row** containing **items**. If necessary, the column
        count is increased to the size of **items**.

        **See also** **takeRow** (), **appendRow** (), and **insertColumn** ().
        """
        ...

    @typing.overload
    def insertRow(self, arow: int, aitem: "QStandardItem") -> None:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#insertRow-1

        **void QStandardItemModel::insertRow(int row , QStandardItem * item )**

        This is an overloaded function.

        Inserts a row at **row** containing **item**.

        When building a list or a tree that has only one column, this function
        provides a convenient way to append a single new item.
        """
        ...

    @typing.overload
    def insertRow(self, row: int, parent: QtCore.QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#insertRow-2

        **bool QStandardItemModel::insertRow(int row , const QModelIndex &
        parent = QModelIndex())**

        Inserts a single row before the given **row** in the child items of the
        **parent** specified. Returns `true` if the row is inserted; otherwise
        returns `false`.

        **See also** **insertRows** (), **insertColumn** (), and **removeRow**
        ().
        """
        ...

    def appendColumn(self, items: typing.Iterable["QStandardItem"]) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#appendColumn

        **void QStandardItemModel::appendColumn(const QList<QStandardItem *> &
        items )**

        Appends a column containing **items**. If necessary, the row count is
        increased to the size of **items**.

        **See also** **insertColumn** () and **appendRow** ().
        """
        ...

    @typing.overload
    def appendRow(self, items: typing.Iterable["QStandardItem"]) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#appendRow

        **void QStandardItemModel::appendRow(const QList<QStandardItem *> &
        items )**

        Appends a row containing **items**. If necessary, the column count is
        increased to the size of **items**.

        **See also** **insertRow** () and **appendColumn** ().
        """
        ...

    @typing.overload
    def appendRow(self, aitem: "QStandardItem") -> None:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#appendRow-1

        **void QStandardItemModel::appendRow(QStandardItem * item )**

        This is an overloaded function.

        When building a list or a tree that has only one column, this function
        provides a convenient way to append a single new **item**.
        """
        ...

    def setColumnCount(self, columns: int) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#setColumnCount

        **void QStandardItemModel::setColumnCount(int columns )**

        Sets the number of columns in this model to **columns**. If this is less
        than **columnCount** (), the data in the unwanted columns is discarded.

        **See also** **columnCount** () and **setRowCount** ().
        """
        ...

    def setRowCount(self, rows: int) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#setRowCount

        **void QStandardItemModel::setRowCount(int rows )**

        Sets the number of rows in this model to **rows**. If this is less than
        **rowCount** (), the data in the unwanted rows is discarded.

        **See also** **rowCount** () and **setColumnCount** ().
        """
        ...

    def setVerticalHeaderLabels(self, labels: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#setVerticalHeaderLabels

        **void QStandardItemModel::setVerticalHeaderLabels(const QStringList &
        labels )**

        Sets the vertical header labels using **labels**. If necessary, the row
        count is increased to the size of **labels**.

        **See also** **setVerticalHeaderItem** ().
        """
        ...

    def setHorizontalHeaderLabels(self, labels: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#setHorizontalHeaderLabels

        **void QStandardItemModel::setHorizontalHeaderLabels(const QStringList &
        labels )**

        Sets the horizontal header labels using **labels**. If necessary, the
        column count is increased to the size of **labels**.

        **See also** **setHorizontalHeaderItem** ().
        """
        ...

    def setVerticalHeaderItem(self, row: int, item: "QStandardItem") -> None:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#setVerticalHeaderItem

        **void QStandardItemModel::setVerticalHeaderItem(int row , QStandardItem
        * item )**

        Sets the vertical header item for **row** to **item**. The model takes
        ownership of the item. If necessary, the row count is increased to fit
        the item. The previous header item (if there was one) is deleted.

        **See also** **verticalHeaderItem** (), **setVerticalHeaderLabels** (),
        and **setHorizontalHeaderItem** ().
        """
        ...

    def verticalHeaderItem(self, row: int) -> "QStandardItem":
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#verticalHeaderItem

        **QStandardItem *QStandardItemModel::verticalHeaderItem(int row )
        const**

        Returns the vertical header item for row **row** if one has been set;
        otherwise returns `nullptr`.

        **See also** **setVerticalHeaderItem** () and **horizontalHeaderItem**
        ().
        """
        ...

    def setHorizontalHeaderItem(self, column: int, item: "QStandardItem") -> None:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#setHorizontalHeaderItem

        **void QStandardItemModel::setHorizontalHeaderItem(int column ,
        QStandardItem * item )**

        Sets the horizontal header item for **column** to **item**. The model
        takes ownership of the item. If necessary, the column count is increased
        to fit the item. The previous header item (if there was one) is deleted.

        **See also** **horizontalHeaderItem** (), **setHorizontalHeaderLabels**
        (), and **setVerticalHeaderItem** ().
        """
        ...

    def horizontalHeaderItem(self, column: int) -> "QStandardItem":
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#horizontalHeaderItem

        **QStandardItem *QStandardItemModel::horizontalHeaderItem(int column )
        const**

        Returns the horizontal header item for **column** if one has been set;
        otherwise returns `nullptr`.

        **See also** **setHorizontalHeaderItem** () and **verticalHeaderItem**
        ().
        """
        ...

    def invisibleRootItem(self) -> "QStandardItem":
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#invisibleRootItem

        **QStandardItem *QStandardItemModel::invisibleRootItem() const**

        Returns the model's invisible root item.

        The invisible root item provides access to the model's top-level items
        through the **QStandardItem**  API, making it possible to write
        functions that can treat top-level items and their children in a uniform
        way; for example, recursive functions involving a tree model.

        **Note:** Calling **index** () on the **QStandardItem**  object
        retrieved from this function is not valid.
        """
        ...

    @typing.overload
    def setItem(self, row: int, column: int, item: "QStandardItem") -> None:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#setItem

        **void QStandardItemModel::setItem(int row , int column , QStandardItem
        * item )**

        Sets the item for the given **row** and **column** to **item**. The
        model takes ownership of the item. If necessary, the row count and
        column count are increased to fit the item. The previous item at the
        given location (if there was one) is deleted.

        **See also** **item** ().
        """
        ...

    @typing.overload
    def setItem(self, arow: int, aitem: "QStandardItem") -> None:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#setItem-1

        **void QStandardItemModel::setItem(int row , QStandardItem * item )**

        This is an overloaded function.
        """
        ...

    def item(self, row: int, column: int = ...) -> "QStandardItem":
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#item

        **QStandardItem *QStandardItemModel::item(int row , int column = 0)
        const**

        Returns the item for the given **row** and **column** if one has been
        set; otherwise returns `nullptr`.

        **See also** **setItem** (), **takeItem** (), and **itemFromIndex** ().
        """
        ...

    def indexFromItem(self, item: "QStandardItem") -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#indexFromItem

        **QModelIndex QStandardItemModel::indexFromItem(const QStandardItem *
        item ) const**

        Returns the **QModelIndex**  associated with the given **item**.

        Use this function when you want to perform an operation that requires
        the **QModelIndex**  of the item, such as
        **QAbstractItemView::scrollTo** (). **QStandardItem::index** () is
        provided as convenience; it is equivalent to calling this function.

        **See also** **itemFromIndex** () and **QStandardItem::index** ().
        """
        ...

    def itemFromIndex(self, index: QtCore.QModelIndex) -> "QStandardItem":
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#itemFromIndex

        **QStandardItem *QStandardItemModel::itemFromIndex(const QModelIndex &
        index ) const**

        Returns a pointer to the **QStandardItem**  associated with the given
        **index**.

        Calling this function is typically the initial step when processing
        **QModelIndex** -based signals from a view, such as
        **QAbstractItemView::activated** (). In your slot, you call
        itemFromIndex(), with the **QModelIndex**  carried by the signal as
        argument, to obtain a pointer to the corresponding **QStandardItem** .

        Note that this function will lazily create an item for the index (using
        **itemPrototype** ()), and set it in the parent item's child table, if
        no item already exists at that index.

        If **index** is an invalid index, this function returns `nullptr`.

        **See also** **indexFromItem** ().
        """
        ...

    def sort(self, column: int, order: QtCore.Qt.SortOrder = ...) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#sort

        **[override virtual] void QStandardItemModel::sort(int column ,
        Qt::SortOrder order = Qt::AscendingOrder)**

        Reimplements: **QAbstractItemModel::sort** (int column, Qt::SortOrder
        order).
        """
        ...

    def setItemData(
        self, index: QtCore.QModelIndex, roles: typing.Dict[int, typing.Any]
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#setItemData

        **[override virtual] bool QStandardItemModel::setItemData(const
        QModelIndex & index , const QMap<int, QVariant> & roles )**

        Reimplements: **QAbstractItemModel::setItemData** (const QModelIndex
        &index, const QMap<int, QVariant> &roles).

        **See also** **itemData** ().
        """
        ...

    def itemData(self, index: QtCore.QModelIndex) -> typing.Dict[int, typing.Any]:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#itemData

        **[override virtual] QMap<int, QVariant>
        QStandardItemModel::itemData(const QModelIndex & index ) const**

        Reimplements: **QAbstractItemModel::itemData(const QModelIndex &index)
        const** .

        **See also** **setItemData** ().
        """
        ...

    def supportedDropActions(self) -> QtCore.Qt.DropAction:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#supportedDropActions

        **[override virtual] Qt::DropActions
        QStandardItemModel::supportedDropActions() const**

        Reimplements: **QAbstractItemModel::supportedDropActions() const** .

        **QStandardItemModel**  supports both copy and move.
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#clear

        **void QStandardItemModel::clear()**

        Removes all items (including header items) from the model and sets the
        number of rows and columns to zero.

        **See also** **removeColumns** () and **removeRows** ().
        """
        ...

    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#flags

        **[override virtual] Qt::ItemFlags QStandardItemModel::flags(const
        QModelIndex & index ) const**

        Reimplements: **QAbstractItemModel::flags(const QModelIndex &index)
        const** .
        """
        ...

    def removeColumns(
        self, column: int, count: int, parent: QtCore.QModelIndex = ...
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#removeColumns

        **[override virtual] bool QStandardItemModel::removeColumns(int column ,
        int count , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QAbstractItemModel::removeColumns** (int column, int
        count, const QModelIndex &parent).
        """
        ...

    def removeRows(
        self, row: int, count: int, parent: QtCore.QModelIndex = ...
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#removeRows

        **[override virtual] bool QStandardItemModel::removeRows(int row , int
        count , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QAbstractItemModel::removeRows** (int row, int count,
        const QModelIndex &parent).
        """
        ...

    def insertColumns(
        self, column: int, count: int, parent: QtCore.QModelIndex = ...
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#insertColumns

        **[override virtual] bool QStandardItemModel::insertColumns(int column ,
        int count , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QAbstractItemModel::insertColumns** (int column, int
        count, const QModelIndex &parent).
        """
        ...

    def insertRows(
        self, row: int, count: int, parent: QtCore.QModelIndex = ...
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#insertRows

        **[override virtual] bool QStandardItemModel::insertRows(int row , int
        count , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QAbstractItemModel::insertRows** (int row, int count,
        const QModelIndex &parent).
        """
        ...

    def setHeaderData(
        self,
        section: int,
        orientation: QtCore.Qt.Orientation,
        value: typing.Any,
        role: int = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#setHeaderData

        **[override virtual] bool QStandardItemModel::setHeaderData(int section
        , Qt::Orientation orientation , const QVariant & value , int role =
        Qt::EditRole)**

        Reimplements: **QAbstractItemModel::setHeaderData** (int section,
        Qt::Orientation orientation, const QVariant &value, int role).

        **See also** **headerData** ().
        """
        ...

    def headerData(
        self, section: int, orientation: QtCore.Qt.Orientation, role: int = ...
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#headerData

        **[override virtual] QVariant QStandardItemModel::headerData(int section
        , Qt::Orientation orientation , int role = Qt::DisplayRole) const**

        Reimplements: **QAbstractItemModel::headerData(int section,
        Qt::Orientation orientation, int role) const** .

        **See also** **setHeaderData** ().
        """
        ...

    def setData(
        self, index: QtCore.QModelIndex, value: typing.Any, role: int = ...
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#setData

        **[override virtual] bool QStandardItemModel::setData(const QModelIndex
        & index , const QVariant & value , int role = Qt::EditRole)**

        Reimplements: **QAbstractItemModel::setData** (const QModelIndex &index,
        const QVariant &value, int role).

        **See also** **data** ().
        """
        ...

    def data(self, index: QtCore.QModelIndex, role: int = ...) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#data

        **[override virtual] QVariant QStandardItemModel::data(const QModelIndex
        & index , int role = Qt::DisplayRole) const**

        Reimplements: **QAbstractItemModel::data(const QModelIndex &index, int
        role) const** .

        **See also** **setData** ().
        """
        ...

    def hasChildren(self, parent: QtCore.QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#hasChildren

        **[override virtual] bool QStandardItemModel::hasChildren(const
        QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::hasChildren(const QModelIndex
        &parent) const** .
        """
        ...

    def columnCount(self, parent: QtCore.QModelIndex = ...) -> int:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#columnCount

        **[override virtual] int QStandardItemModel::columnCount(const
        QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::columnCount(const QModelIndex
        &parent) const** .

        **See also** **setColumnCount** ().
        """
        ...

    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#rowCount

        **[override virtual] int QStandardItemModel::rowCount(const QModelIndex
        & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::rowCount(const QModelIndex &parent)
        const** .

        **See also** **setRowCount** ().
        """
        ...

    @typing.overload
    def parent(self, child: QtCore.QModelIndex) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#parent

        **[override virtual] QModelIndex QStandardItemModel::parent(const
        QModelIndex & child ) const**

        Reimplements: **QAbstractItemModel::parent(const QModelIndex &index)
        const** .
        """
        ...

    @typing.overload
    def parent(self) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#parent

        **[override virtual] QModelIndex QStandardItemModel::parent(const
        QModelIndex & child ) const**

        Reimplements: **QAbstractItemModel::parent(const QModelIndex &index)
        const** .
        """
        ...

    def index(
        self, row: int, column: int, parent: QtCore.QModelIndex = ...
    ) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#index

        **[override virtual] QModelIndex QStandardItemModel::index(int row , int
        column , const QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::index(int row, int column, const
        QModelIndex &parent) const** .
        """
        ...

    @property
    def itemChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qstandarditemmodel.html#itemChanged

        **[signal] void QStandardItemModel::itemChanged(QStandardItem * item )**

        This signal is emitted whenever the data of **item** has changed.
        """
        ...
